@@ -3,7 +3,6 @@ var searchData=
   ['imb_5ferrno_0',['imb_errno',['../structIMB__MGR.html#a0ab7a3dfdfd8442f591699e2310df11f',1,'IMB_MGR']]],
   ['in_1',['in',['../structIMB__SGL__IOV.html#a56c5b0a033d949869cee2d03f1df3129',1,'IMB_SGL_IOV']]],
   ['in_5flength_2',['in_length',['../structgcm__context__data.html#a0d9e72f85aba9363fcb4f2d757342aa2',1,'gcm_context_data']]],
-  ['iv_3',['iv',['../structIMB__JOB.html#a960fdd62c1c10d2d3cc0a765c0a6531d',1,'IMB_JOB']]],
-  ['iv_4',['IV',['../structchacha20__poly1305__context__data.html#ac0d1657fc57308900691369362c56658',1,'chacha20_poly1305_context_data']]],
-  ['iv_5flen_5fin_5fbytes_5',['iv_len_in_bytes',['../structIMB__JOB.html#a25b4ce8aec20f64cfc393b245d62a09e',1,'IMB_JOB']]]
+  ['iv_3',['iv',['../structIMB__JOB.html#a960fdd62c1c10d2d3cc0a765c0a6531d',1,'IMB_JOB::iv'],['../structchacha20__poly1305__context__data.html#a576d50687b0bc16916b01f1364fd5845',1,'chacha20_poly1305_context_data::IV']]],
+  ['iv_5flen_5fin_5fbytes_4',['iv_len_in_bytes',['../structIMB__JOB.html#a25b4ce8aec20f64cfc393b245d62a09e',1,'IMB_JOB']]]
 ];
