@@ -1,5 +1,5 @@
 /*******************************************************************************
- Copyright (c) 2023, Intel Corporation
+ Copyright (c) 2023-2024, Intel Corporation
 
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
@@ -43,13 +43,10 @@
 #include "include/save_xmms.h"
 #include "include/des.h"
 #include "include/cpu_feature.h"
-#include "include/noaesni.h"
-#include "include/aesni_emu.h"
 #include "include/error.h"
 
-#include "include/arch_sse_type1.h" /* poly1305, snow3g */
+#include "include/arch_sse_type1.h" /* poly1305, snow3g, aes-cfb, zuc */
 #include "include/arch_sse_type2.h" /* shani */
-#include "include/arch_avx_type1.h"
 #include "include/arch_avx2_type1.h"
 #include "include/arch_avx2_type2.h"
 #include "include/arch_avx2_type3.h"
@@ -74,6 +71,8 @@
 #define SUBMIT_CIPHER_BURST_NOCHECK submit_cipher_burst_nocheck_avx2_t3
 #define SUBMIT_HASH_BURST           submit_hash_burst_avx2_t3
 #define SUBMIT_HASH_BURST_NOCHECK   submit_hash_burst_nocheck_avx2_t3
+#define SUBMIT_AEAD_BURST           submit_aead_burst_avx2_t3
+#define SUBMIT_AEAD_BURST_NOCHECK   submit_aead_burst_nocheck_avx2_t3
 #define SET_SUITE_ID_FN             set_suite_id_avx2_t3
 
 /* Hash */
@@ -97,17 +96,17 @@
 #define SUBMIT_JOB_AES_GCM_ENC submit_job_gcm_enc_avx2
 
 /* AES-CBC */
-#define SUBMIT_JOB_AES_CBC_128_ENC submit_job_aes128_enc_avx
-#define SUBMIT_JOB_AES_CBC_128_DEC submit_job_aes128_dec_avx
-#define FLUSH_JOB_AES_CBC_128_ENC  flush_job_aes128_enc_avx
+#define SUBMIT_JOB_AES_CBC_128_ENC submit_job_aes128_cbc_enc_avx
+#define SUBMIT_JOB_AES_CBC_128_DEC submit_job_aes128_cbc_dec_avx
+#define FLUSH_JOB_AES_CBC_128_ENC  flush_job_aes128_cbc_enc_avx
 
-#define SUBMIT_JOB_AES_CBC_192_ENC submit_job_aes192_enc_avx
-#define SUBMIT_JOB_AES_CBC_192_DEC submit_job_aes192_dec_avx
-#define FLUSH_JOB_AES_CBC_192_ENC  flush_job_aes192_enc_avx
+#define SUBMIT_JOB_AES_CBC_192_ENC submit_job_aes192_cbc_enc_avx
+#define SUBMIT_JOB_AES_CBC_192_DEC submit_job_aes192_cbc_dec_avx
+#define FLUSH_JOB_AES_CBC_192_ENC  flush_job_aes192_cbc_enc_avx
 
-#define SUBMIT_JOB_AES_CBC_256_ENC submit_job_aes256_enc_avx
-#define SUBMIT_JOB_AES_CBC_256_DEC submit_job_aes256_dec_avx
-#define FLUSH_JOB_AES_CBC_256_ENC  flush_job_aes256_enc_avx
+#define SUBMIT_JOB_AES_CBC_256_ENC submit_job_aes256_cbc_enc_avx
+#define SUBMIT_JOB_AES_CBC_256_DEC submit_job_aes256_cbc_dec_avx
+#define FLUSH_JOB_AES_CBC_256_ENC  flush_job_aes256_cbc_enc_avx
 
 #define AES_CBC_DEC_128 aes_cbc_dec_128_avx
 #define AES_CBC_DEC_192 aes_cbc_dec_192_avx
@@ -135,13 +134,21 @@
 #define AES_ECB_DEC_256 aes_ecb_dec_256_vaes_avx2
 
 /* AES-CTR */
-#define AES_CTR_128     aes_cntr_128_avx
-#define AES_CTR_192     aes_cntr_192_avx
-#define AES_CTR_256     aes_cntr_256_avx
+#define AES_CTR_128     aes_cntr_128_vaes_avx2
+#define AES_CTR_192     aes_cntr_192_vaes_avx2
+#define AES_CTR_256     aes_cntr_256_vaes_avx2
 #define AES_CTR_128_BIT aes_cntr_bit_128_avx
 #define AES_CTR_192_BIT aes_cntr_bit_192_avx
 #define AES_CTR_256_BIT aes_cntr_bit_256_avx
 
+/* AES-CFB */
+#define AES_CFB_128_ENC aes_cfb_128_enc_sse
+#define AES_CFB_192_ENC aes_cfb_192_enc_sse
+#define AES_CFB_256_ENC aes_cfb_256_enc_sse
+#define AES_CFB_128_DEC aes_cfb_128_dec_sse
+#define AES_CFB_192_DEC aes_cfb_192_dec_sse
+#define AES_CFB_256_DEC aes_cfb_256_dec_sse
+
 /* AES-CCM */
 #define AES_CNTR_CCM_128 aes_cntr_ccm_128_avx
 #define AES_CNTR_CCM_256 aes_cntr_ccm_256_avx
@@ -160,8 +167,8 @@
 #define SUBMIT_JOB_AES256_CMAC_AUTH submit_job_aes256_cmac_auth_avx
 
 /* AES-CFB */
-#define AES_CFB_128_ONE aes_cfb_128_one_avx2
-#define AES_CFB_256_ONE aes_cfb_256_one_avx2
+#define AES_CFB_128_ONE aes_cfb_128_one_avx
+#define AES_CFB_256_ONE aes_cfb_256_one_avx
 
 /* AES-XCBC */
 #define SUBMIT_JOB_AES_XCBC submit_job_aes_xcbc_avx
@@ -252,6 +259,13 @@ flush_snow3g_uea2_job_avx2_t2(IMB_MGR *state)
 #define SM4_ECB     sm4_ecb_sse
 #define SM4_CBC_ENC sm4_cbc_enc_sse
 #define SM4_CBC_DEC sm4_cbc_dec_sse
+#define SM4_CTR     sm4_ctr_sse
+
+/* SM3 */
+#define SUBMIT_JOB_SM3      sm3_msg_submit_sse
+#define FLUSH_JOB_SM3       unused
+#define SUBMIT_JOB_HMAC_SM3 sm3_hmac_submit_sse
+#define FLUSH_JOB_HMAC_SM3  unused
 
 static void
 reset_ooo_mgrs(IMB_MGR *state)
@@ -329,6 +343,11 @@ reset_ooo_mgrs(IMB_MGR *state)
 
         /* Init SNOW3G-UIA out-of-order fields */
         ooo_mgr_snow3g_reset(state->snow3g_uia2_ooo, 4);
+
+        /*  Init AES-CFB out-of-order fields */
+        ooo_mgr_aes_reset(state->aes_cfb_128_ooo, 1);
+        ooo_mgr_aes_reset(state->aes_cfb_192_ooo, 1);
+        ooo_mgr_aes_reset(state->aes_cfb_256_ooo, 1);
 }
 
 IMB_DLL_LOCAL void
@@ -343,6 +362,9 @@ init_mb_mgr_avx2_t3_internal(IMB_MGR *state, const int reset_mgrs)
         /* Set architecture for future checks */
         state->used_arch = (uint32_t) IMB_ARCH_AVX2;
 
+        /* Set architecture type for future checks */
+        state->used_arch_type = 3;
+
         if (reset_mgrs) {
                 reset_ooo_mgrs(state);
 
@@ -366,6 +388,8 @@ init_mb_mgr_avx2_t3_internal(IMB_MGR *state, const int reset_mgrs)
         state->submit_cipher_burst_nocheck = SUBMIT_CIPHER_BURST_NOCHECK;
         state->submit_hash_burst = SUBMIT_HASH_BURST;
         state->submit_hash_burst_nocheck = SUBMIT_HASH_BURST_NOCHECK;
+        state->submit_aead_burst = SUBMIT_AEAD_BURST;
+        state->submit_aead_burst_nocheck = SUBMIT_AEAD_BURST_NOCHECK;
         state->set_suite_id = SET_SUITE_ID_FN;
 
         state->keyexp_128 = aes_keyexp_128_avx2;
@@ -390,26 +414,26 @@ init_mb_mgr_avx2_t3_internal(IMB_MGR *state, const int reset_mgrs)
         state->sha512 = sha512_avx2;
         state->md5_one_block = md5_one_block_avx2;
 
-        state->aes128_cfb_one = aes_cfb_128_one_avx2;
-        state->aes256_cfb_one = aes_cfb_256_one_avx2;
+        state->aes128_cfb_one = aes_cfb_128_one_avx;
+        state->aes256_cfb_one = aes_cfb_256_one_avx;
 
         state->eea3_1_buffer = zuc_eea3_1_buffer_avx2;
-        state->eea3_4_buffer = zuc_eea3_4_buffer_avx;
+        state->eea3_4_buffer = zuc_eea3_4_buffer_sse;
         state->eea3_n_buffer = zuc_eea3_n_buffer_avx2;
         state->eia3_1_buffer = zuc_eia3_1_buffer_avx2;
         state->eia3_n_buffer = zuc_eia3_n_buffer_avx2;
 
-        state->f8_1_buffer = kasumi_f8_1_buffer_avx;
-        state->f8_1_buffer_bit = kasumi_f8_1_buffer_bit_avx;
-        state->f8_2_buffer = kasumi_f8_2_buffer_avx;
-        state->f8_3_buffer = kasumi_f8_3_buffer_avx;
-        state->f8_4_buffer = kasumi_f8_4_buffer_avx;
-        state->f8_n_buffer = kasumi_f8_n_buffer_avx;
-        state->f9_1_buffer = kasumi_f9_1_buffer_avx;
-        state->f9_1_buffer_user = kasumi_f9_1_buffer_user_avx;
-        state->kasumi_init_f8_key_sched = kasumi_init_f8_key_sched_avx;
-        state->kasumi_init_f9_key_sched = kasumi_init_f9_key_sched_avx;
-        state->kasumi_key_sched_size = kasumi_key_sched_size_avx;
+        state->f8_1_buffer = kasumi_f8_1_buffer_sse;
+        state->f8_1_buffer_bit = kasumi_f8_1_buffer_bit_sse;
+        state->f8_2_buffer = kasumi_f8_2_buffer_sse;
+        state->f8_3_buffer = kasumi_f8_3_buffer_sse;
+        state->f8_4_buffer = kasumi_f8_4_buffer_sse;
+        state->f8_n_buffer = kasumi_f8_n_buffer_sse;
+        state->f9_1_buffer = kasumi_f9_1_buffer_sse;
+        state->f9_1_buffer_user = kasumi_f9_1_buffer_user_sse;
+        state->kasumi_init_f8_key_sched = kasumi_init_f8_key_sched_sse;
+        state->kasumi_init_f9_key_sched = kasumi_init_f9_key_sched_sse;
+        state->kasumi_key_sched_size = kasumi_key_sched_size_sse;
 
         state->snow3g_f8_1_buffer_bit = snow3g_f8_1_buffer_bit_avx2;
         state->snow3g_f8_1_buffer = snow3g_f8_1_buffer_avx2;
