@@ -1,5 +1,5 @@
 /*******************************************************************************
- Copyright (c) 2022-2023, Intel Corporation
+ Copyright (c) 2022-2024, Intel Corporation
 
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
@@ -44,15 +44,12 @@
 #include "include/des.h"
 #include "include/gcm.h"
 #include "include/cpu_feature.h"
-#include "include/noaesni.h"
-#include "include/aesni_emu.h"
 #include "include/error.h"
 
-#include "include/arch_avx_type1.h"  /* AESNI */
-#include "include/arch_avx2_type1.h" /* MD5 */
+#include "include/arch_avx2_type1.h" /* AESNI, MD5 */
 #include "include/arch_avx512_type1.h"
 #include "include/arch_avx512_type2.h"
-#include "include/arch_sse_type1.h"
+#include "include/arch_sse_type1.h" /* aes-cfb, zuc */
 
 #include "include/ooo_mgr_reset.h"
 
@@ -74,6 +71,8 @@
 #define SUBMIT_CIPHER_BURST_NOCHECK submit_cipher_burst_nocheck_avx512_t1
 #define SUBMIT_HASH_BURST           submit_hash_burst_avx512_t1
 #define SUBMIT_HASH_BURST_NOCHECK   submit_hash_burst_nocheck_avx512_t1
+#define SUBMIT_AEAD_BURST           submit_aead_burst_avx512_t1
+#define SUBMIT_AEAD_BURST_NOCHECK   submit_aead_burst_nocheck_avx512_t1
 #define SET_SUITE_ID_FN             set_suite_id_avx512_t1
 
 /* Hash */
@@ -97,17 +96,17 @@
 #define SUBMIT_JOB_AES_GCM_ENC submit_job_gcm_enc_avx512
 
 /* AES-CBC */
-#define SUBMIT_JOB_AES_CBC_128_ENC submit_job_aes128_enc_avx
-#define SUBMIT_JOB_AES_CBC_128_DEC submit_job_aes128_dec_avx
-#define FLUSH_JOB_AES_CBC_128_ENC  flush_job_aes128_enc_avx
+#define SUBMIT_JOB_AES_CBC_128_ENC submit_job_aes128_cbc_enc_avx
+#define SUBMIT_JOB_AES_CBC_128_DEC submit_job_aes128_cbc_dec_avx
+#define FLUSH_JOB_AES_CBC_128_ENC  flush_job_aes128_cbc_enc_avx
 
-#define SUBMIT_JOB_AES_CBC_192_ENC submit_job_aes192_enc_avx
-#define SUBMIT_JOB_AES_CBC_192_DEC submit_job_aes192_dec_avx
-#define FLUSH_JOB_AES_CBC_192_ENC  flush_job_aes192_enc_avx
+#define SUBMIT_JOB_AES_CBC_192_ENC submit_job_aes192_cbc_enc_avx
+#define SUBMIT_JOB_AES_CBC_192_DEC submit_job_aes192_cbc_dec_avx
+#define FLUSH_JOB_AES_CBC_192_ENC  flush_job_aes192_cbc_enc_avx
 
-#define SUBMIT_JOB_AES_CBC_256_ENC submit_job_aes256_enc_avx
-#define SUBMIT_JOB_AES_CBC_256_DEC submit_job_aes256_dec_avx
-#define FLUSH_JOB_AES_CBC_256_ENC  flush_job_aes256_enc_avx
+#define SUBMIT_JOB_AES_CBC_256_ENC submit_job_aes256_cbc_enc_avx
+#define SUBMIT_JOB_AES_CBC_256_DEC submit_job_aes256_cbc_dec_avx
+#define FLUSH_JOB_AES_CBC_256_ENC  flush_job_aes256_cbc_enc_avx
 
 #define AES_CBC_DEC_128 aes_cbc_dec_128_avx
 #define AES_CBC_DEC_192 aes_cbc_dec_192_avx
@@ -142,6 +141,14 @@
 #define AES_CTR_192_BIT aes_cntr_bit_192_avx
 #define AES_CTR_256_BIT aes_cntr_bit_256_avx
 
+/* AES-CFB */
+#define AES_CFB_128_ENC aes_cfb_128_enc_sse
+#define AES_CFB_192_ENC aes_cfb_192_enc_sse
+#define AES_CFB_256_ENC aes_cfb_256_enc_sse
+#define AES_CFB_128_DEC aes_cfb_128_dec_sse
+#define AES_CFB_192_DEC aes_cfb_192_dec_sse
+#define AES_CFB_256_DEC aes_cfb_256_dec_sse
+
 /* AES-CCM */
 #define AES_CNTR_CCM_128 aes_cntr_ccm_128_avx
 #define AES_CNTR_CCM_256 aes_cntr_ccm_256_avx
@@ -160,8 +167,8 @@
 #define SUBMIT_JOB_AES256_CMAC_AUTH submit_job_aes256_cmac_auth_avx
 
 /* AES-CFB */
-#define AES_CFB_128_ONE aes_cfb_128_one_avx512
-#define AES_CFB_256_ONE aes_cfb_256_one_avx512
+#define AES_CFB_128_ONE aes_cfb_128_one_avx
+#define AES_CFB_256_ONE aes_cfb_256_one_avx
 
 /* AES-XCBC */
 #define SUBMIT_JOB_AES_XCBC submit_job_aes_xcbc_avx
@@ -326,11 +333,6 @@ submit_aes_docsis256_dec_crc32_avx512(MB_MGR_DOCSIS_AES_OOO *state, IMB_JOB *job
         return job;
 }
 
-/* SM4 */
-#define SM4_ECB     sm4_ecb_sse
-#define SM4_CBC_ENC sm4_cbc_enc_sse
-#define SM4_CBC_DEC sm4_cbc_dec_sse
-
 #define SUBMIT_JOB_DOCSIS128_SEC_CRC_ENC submit_job_aes_docsis128_enc_crc32_avx512
 #define SUBMIT_JOB_DOCSIS256_SEC_CRC_ENC submit_job_aes_docsis256_enc_crc32_avx512
 #define FLUSH_JOB_DOCSIS128_SEC_CRC_ENC  flush_job_aes_docsis128_enc_crc32_avx512
@@ -338,6 +340,18 @@ submit_aes_docsis256_dec_crc32_avx512(MB_MGR_DOCSIS_AES_OOO *state, IMB_JOB *job
 #define SUBMIT_JOB_DOCSIS128_SEC_CRC_DEC submit_aes_docsis128_dec_crc32_avx512
 #define SUBMIT_JOB_DOCSIS256_SEC_CRC_DEC submit_aes_docsis256_dec_crc32_avx512
 
+/* SM4 */
+#define SM4_ECB     sm4_ecb_sse
+#define SM4_CBC_ENC sm4_cbc_enc_sse
+#define SM4_CBC_DEC sm4_cbc_dec_sse
+#define SM4_CTR     sm4_ctr_sse
+
+/* SM3 */
+#define SUBMIT_JOB_SM3      sm3_msg_submit_sse
+#define FLUSH_JOB_SM3       unused
+#define SUBMIT_JOB_HMAC_SM3 sm3_hmac_submit_sse
+#define FLUSH_JOB_HMAC_SM3  unused
+
 /* ====================================================================== */
 
 static void
@@ -422,6 +436,11 @@ reset_ooo_mgrs(IMB_MGR *state)
 
         /* Init SHA512 out-of-order fields */
         ooo_mgr_sha512_reset(state->sha_512_ooo, AVX512_NUM_SHA512_LANES);
+
+        /*  Init AES-CFB out-of-order fields */
+        ooo_mgr_aes_reset(state->aes_cfb_128_ooo, 1);
+        ooo_mgr_aes_reset(state->aes_cfb_192_ooo, 1);
+        ooo_mgr_aes_reset(state->aes_cfb_256_ooo, 1);
 }
 
 IMB_DLL_LOCAL void
@@ -436,6 +455,9 @@ init_mb_mgr_avx512_t1_internal(IMB_MGR *state, const int reset_mgrs)
         /* Set architecture for future checks */
         state->used_arch = (uint32_t) IMB_ARCH_AVX512;
 
+        /* Set architecture type for future checks */
+        state->used_arch_type = 1;
+
         if (reset_mgrs) {
                 reset_ooo_mgrs(state);
 
@@ -459,6 +481,8 @@ init_mb_mgr_avx512_t1_internal(IMB_MGR *state, const int reset_mgrs)
         state->submit_cipher_burst_nocheck = SUBMIT_CIPHER_BURST_NOCHECK;
         state->submit_hash_burst = SUBMIT_HASH_BURST;
         state->submit_hash_burst_nocheck = SUBMIT_HASH_BURST_NOCHECK;
+        state->submit_aead_burst = SUBMIT_AEAD_BURST;
+        state->submit_aead_burst_nocheck = SUBMIT_AEAD_BURST_NOCHECK;
         state->set_suite_id = SET_SUITE_ID_FN;
 
         state->keyexp_128 = aes_keyexp_128_avx512;
@@ -482,26 +506,26 @@ init_mb_mgr_avx512_t1_internal(IMB_MGR *state, const int reset_mgrs)
         state->sha512 = sha512_avx512;
         state->md5_one_block = md5_one_block_avx512;
 
-        state->aes128_cfb_one = aes_cfb_128_one_avx512;
-        state->aes256_cfb_one = aes_cfb_256_one_avx512;
+        state->aes128_cfb_one = aes_cfb_128_one_avx;
+        state->aes256_cfb_one = aes_cfb_256_one_avx;
 
         state->eea3_1_buffer = zuc_eea3_1_buffer_avx512;
-        state->eea3_4_buffer = zuc_eea3_4_buffer_avx;
+        state->eea3_4_buffer = zuc_eea3_4_buffer_sse;
         state->eia3_1_buffer = zuc_eia3_1_buffer_avx512;
         state->eea3_n_buffer = zuc_eea3_n_buffer_avx512;
         state->eia3_n_buffer = zuc_eia3_n_buffer_avx512;
 
-        state->f8_1_buffer = kasumi_f8_1_buffer_avx;
-        state->f8_1_buffer_bit = kasumi_f8_1_buffer_bit_avx;
-        state->f8_2_buffer = kasumi_f8_2_buffer_avx;
-        state->f8_3_buffer = kasumi_f8_3_buffer_avx;
-        state->f8_4_buffer = kasumi_f8_4_buffer_avx;
-        state->f8_n_buffer = kasumi_f8_n_buffer_avx;
-        state->f9_1_buffer = kasumi_f9_1_buffer_avx;
-        state->f9_1_buffer_user = kasumi_f9_1_buffer_user_avx;
-        state->kasumi_init_f8_key_sched = kasumi_init_f8_key_sched_avx;
-        state->kasumi_init_f9_key_sched = kasumi_init_f9_key_sched_avx;
-        state->kasumi_key_sched_size = kasumi_key_sched_size_avx;
+        state->f8_1_buffer = kasumi_f8_1_buffer_sse;
+        state->f8_1_buffer_bit = kasumi_f8_1_buffer_bit_sse;
+        state->f8_2_buffer = kasumi_f8_2_buffer_sse;
+        state->f8_3_buffer = kasumi_f8_3_buffer_sse;
+        state->f8_4_buffer = kasumi_f8_4_buffer_sse;
+        state->f8_n_buffer = kasumi_f8_n_buffer_sse;
+        state->f9_1_buffer = kasumi_f9_1_buffer_sse;
+        state->f9_1_buffer_user = kasumi_f9_1_buffer_user_sse;
+        state->kasumi_init_f8_key_sched = kasumi_init_f8_key_sched_sse;
+        state->kasumi_init_f9_key_sched = kasumi_init_f9_key_sched_sse;
+        state->kasumi_key_sched_size = kasumi_key_sched_size_sse;
 
         state->snow3g_f8_1_buffer_bit = snow3g_f8_1_buffer_bit_avx512;
         state->snow3g_f8_1_buffer = snow3g_f8_1_buffer_avx512;
