@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2020-2023, Intel Corporation
+  Copyright (c) 2020-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -35,8 +35,6 @@
 IMB_JOB *
 aead_chacha20_poly1305_sse(IMB_MGR *mgr, IMB_JOB *job);
 IMB_JOB *
-aead_chacha20_poly1305_avx(IMB_MGR *mgr, IMB_JOB *job);
-IMB_JOB *
 aead_chacha20_poly1305_avx2(IMB_MGR *mgr, IMB_JOB *job);
 IMB_JOB *
 aead_chacha20_poly1305_avx512(IMB_MGR *mgr, IMB_JOB *job);
@@ -44,8 +42,6 @@ aead_chacha20_poly1305_avx512(IMB_MGR *mgr, IMB_JOB *job);
 IMB_JOB *
 aead_chacha20_poly1305_sgl_sse(IMB_MGR *mgr, IMB_JOB *job);
 IMB_JOB *
-aead_chacha20_poly1305_sgl_avx(IMB_MGR *mgr, IMB_JOB *job);
-IMB_JOB *
 aead_chacha20_poly1305_sgl_avx2(IMB_MGR *mgr, IMB_JOB *job);
 IMB_JOB *
 aead_chacha20_poly1305_sgl_avx512(IMB_MGR *mgr, IMB_JOB *job);
@@ -59,11 +55,6 @@ chacha20_enc_dec_ks_sse(const void *src, void *dst, const uint64_t length, const
 IMB_JOB *
 submit_job_chacha20_poly_dec_sse(IMB_JOB *, const void *ks, const uint64_t len_to_xor);
 IMB_JOB *
-submit_job_chacha20_enc_dec_avx(IMB_JOB *);
-void
-chacha20_enc_dec_ks_avx(const void *src, void *dst, const uint64_t length, const void *key,
-                        const struct chacha20_poly1305_context_data *ctx);
-IMB_JOB *
 submit_job_chacha20_enc_dec_avx2(IMB_JOB *);
 void
 chacha20_enc_dec_ks_avx2(const void *src, void *dst, const uint64_t length, const void *key,
@@ -112,9 +103,6 @@ void
 init_chacha20_poly1305_sse(const void *key, struct chacha20_poly1305_context_data *ctx,
                            const void *iv, const void *aad, const uint64_t aad_len);
 void
-init_chacha20_poly1305_avx(const void *key, struct chacha20_poly1305_context_data *ctx,
-                           const void *iv, const void *aad, const uint64_t aad_len);
-void
 init_chacha20_poly1305_avx2(const void *key, struct chacha20_poly1305_context_data *ctx,
                             const void *iv, const void *aad, const uint64_t aad_len);
 #ifdef AVX_IFMA
@@ -132,9 +120,6 @@ void
 update_enc_chacha20_poly1305_sse(const void *key, struct chacha20_poly1305_context_data *ctx,
                                  void *dst, const void *src, const uint64_t len);
 void
-update_enc_chacha20_poly1305_avx(const void *key, struct chacha20_poly1305_context_data *ctx,
-                                 void *dst, const void *src, const uint64_t len);
-void
 update_enc_chacha20_poly1305_avx2(const void *key, struct chacha20_poly1305_context_data *ctx,
                                   void *dst, const void *src, const uint64_t len);
 #ifdef AVX_IFMA
@@ -152,9 +137,6 @@ void
 update_dec_chacha20_poly1305_sse(const void *key, struct chacha20_poly1305_context_data *ctx,
                                  void *dst, const void *src, const uint64_t len);
 void
-update_dec_chacha20_poly1305_avx(const void *key, struct chacha20_poly1305_context_data *ctx,
-                                 void *dst, const void *src, const uint64_t len);
-void
 update_dec_chacha20_poly1305_avx2(const void *key, struct chacha20_poly1305_context_data *ctx,
                                   void *dst, const void *src, const uint64_t len);
 #ifdef AVX_IFMA
@@ -172,9 +154,6 @@ void
 finalize_chacha20_poly1305_sse(struct chacha20_poly1305_context_data *ctx, void *tag,
                                const uint64_t tag_len);
 void
-finalize_chacha20_poly1305_avx(struct chacha20_poly1305_context_data *ctx, void *tag,
-                               const uint64_t tag_len);
-void
 finalize_chacha20_poly1305_avx2(struct chacha20_poly1305_context_data *ctx, void *tag,
                                 const uint64_t tag_len);
 #ifdef AVX_IFMA
