@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2012-2023, Intel Corporation
+  Copyright (c) 2012-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -204,6 +204,7 @@ typedef struct {
         IMB_JOB *job_in_lane[16];
         uint64_t num_lanes_inuse;
         DECLARE_ALIGNED(uint64_t lens64[16], 64);
+        uint32_t total_num_lanes;
         uint64_t road_block;
 } MB_MGR_AES_OOO;
 
@@ -254,6 +255,7 @@ typedef struct {
         DECLARE_ALIGNED(IMB_JOB *job_in_lane[16], 16);
         uint64_t num_lanes_inuse;
         DECLARE_ALIGNED(uint8_t init_blocks[16 * (4 * 16)], 64);
+        uint32_t total_num_lanes;
         uint64_t road_block;
 } MB_MGR_CCM_OOO;
 
@@ -269,6 +271,7 @@ typedef struct {
         DECLARE_ALIGNED(IMB_JOB *job_in_lane[16], 16);
         uint64_t num_lanes_inuse;
         DECLARE_ALIGNED(uint8_t scratch[16 * 16], 32);
+        uint32_t total_num_lanes;
         uint64_t road_block;
 } MB_MGR_CMAC_OOO;
 
@@ -333,6 +336,7 @@ typedef struct {
         uint64_t unused_lanes;
         HMAC_SHA1_LANE_DATA ldata[AVX512_NUM_SHA1_LANES];
         uint32_t num_lanes_inuse;
+        uint32_t total_num_lanes;
         uint64_t road_block;
 } MB_MGR_HMAC_SHA_1_OOO;
 
@@ -342,6 +346,7 @@ typedef struct {
         uint64_t unused_lanes;
         HMAC_SHA1_LANE_DATA ldata[AVX512_NUM_SHA1_LANES];
         uint32_t num_lanes_inuse;
+        uint32_t total_num_lanes;
         uint64_t road_block;
 } MB_MGR_SHA_1_OOO;
 
@@ -351,6 +356,7 @@ typedef struct {
         uint64_t unused_lanes;
         HMAC_SHA1_LANE_DATA ldata[AVX512_NUM_SHA256_LANES];
         uint32_t num_lanes_inuse;
+        uint32_t total_num_lanes;
         uint64_t road_block;
 } MB_MGR_HMAC_SHA_256_OOO;
 
@@ -360,6 +366,7 @@ typedef struct {
         uint64_t unused_lanes;
         HMAC_SHA1_LANE_DATA ldata[AVX512_NUM_SHA256_LANES];
         uint32_t num_lanes_inuse;
+        uint32_t total_num_lanes;
         uint64_t road_block;
 } MB_MGR_SHA_256_OOO;
 
@@ -368,6 +375,7 @@ typedef struct {
         DECLARE_ALIGNED(uint16_t lens[8], 16);
         uint64_t unused_lanes;
         HMAC_SHA512_LANE_DATA ldata[AVX512_NUM_SHA512_LANES];
+        uint32_t total_num_lanes;
         uint64_t road_block;
 } MB_MGR_HMAC_SHA_512_OOO;
 
@@ -377,6 +385,7 @@ typedef struct {
         uint64_t unused_lanes;
         HMAC_SHA512_LANE_DATA ldata[AVX512_NUM_SHA512_LANES];
         uint32_t num_lanes_inuse;
+        uint32_t total_num_lanes;
         uint64_t road_block;
 } MB_MGR_SHA_512_OOO;
 
@@ -391,6 +400,7 @@ typedef struct {
         uint64_t unused_lanes;
         HMAC_SHA1_LANE_DATA ldata[AVX512_NUM_MD5_LANES];
         uint32_t num_lanes_inuse;
+        uint32_t total_num_lanes;
         uint64_t road_block;
 } MB_MGR_HMAC_MD5_OOO;
 
@@ -409,8 +419,6 @@ typedef struct {
         uint64_t road_block;
 } MB_MGR_SNOW3G_OOO;
 
-IMB_DLL_LOCAL void
-init_mb_mgr_sse_no_aesni_internal(IMB_MGR *state, const int reset_mgrs);
 IMB_DLL_LOCAL void
 init_mb_mgr_sse_internal(IMB_MGR *state, const int reset_mgrs);
 IMB_DLL_LOCAL void
@@ -420,12 +428,6 @@ init_mb_mgr_sse_t2_internal(IMB_MGR *state, const int reset_mgrs);
 IMB_DLL_LOCAL void
 init_mb_mgr_sse_t3_internal(IMB_MGR *state, const int reset_mgrs);
 IMB_DLL_LOCAL void
-init_mb_mgr_avx_internal(IMB_MGR *state, const int reset_mgrs);
-IMB_DLL_LOCAL void
-init_mb_mgr_avx_t1_internal(IMB_MGR *state, const int reset_mgrs);
-IMB_DLL_LOCAL void
-init_mb_mgr_avx_t2_internal(IMB_MGR *state, const int reset_mgrs);
-IMB_DLL_LOCAL void
 init_mb_mgr_avx2_internal(IMB_MGR *state, const int reset_mgrs);
 IMB_DLL_LOCAL void
 init_mb_mgr_avx2_t1_internal(IMB_MGR *state, const int reset_mgrs);
@@ -434,6 +436,8 @@ init_mb_mgr_avx2_t2_internal(IMB_MGR *state, const int reset_mgrs);
 IMB_DLL_LOCAL void
 init_mb_mgr_avx2_t3_internal(IMB_MGR *state, const int reset_mgrs);
 IMB_DLL_LOCAL void
+init_mb_mgr_avx2_t4_internal(IMB_MGR *state, const int reset_mgrs);
+IMB_DLL_LOCAL void
 init_mb_mgr_avx512_internal(IMB_MGR *state, const int reset_mgrs);
 IMB_DLL_LOCAL void
 init_mb_mgr_avx512_t1_internal(IMB_MGR *state, const int reset_mgrs);
@@ -447,16 +451,14 @@ get_next_burst_sse_t2(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 get_next_burst_sse_t3(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
-get_next_burst_avx_t1(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
-IMB_DLL_EXPORT uint32_t
-get_next_burst_avx_t2(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
-IMB_DLL_EXPORT uint32_t
 get_next_burst_avx2_t1(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 get_next_burst_avx2_t2(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 get_next_burst_avx2_t3(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
+get_next_burst_avx2_t4(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
+IMB_DLL_EXPORT uint32_t
 get_next_burst_avx512_t1(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 get_next_burst_avx512_t2(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
@@ -468,16 +470,14 @@ submit_burst_sse_t2(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 submit_burst_sse_t3(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
-submit_burst_avx_t1(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
-IMB_DLL_EXPORT uint32_t
-submit_burst_avx_t2(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
-IMB_DLL_EXPORT uint32_t
 submit_burst_avx2_t1(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 submit_burst_avx2_t2(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 submit_burst_avx2_t3(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
+submit_burst_avx2_t4(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
+IMB_DLL_EXPORT uint32_t
 submit_burst_avx512_t1(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 submit_burst_avx512_t2(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
@@ -489,16 +489,14 @@ submit_burst_nocheck_sse_t2(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **job
 IMB_DLL_EXPORT uint32_t
 submit_burst_nocheck_sse_t3(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
-submit_burst_nocheck_avx_t1(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
-IMB_DLL_EXPORT uint32_t
-submit_burst_nocheck_avx_t2(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
-IMB_DLL_EXPORT uint32_t
 submit_burst_nocheck_avx2_t1(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 submit_burst_nocheck_avx2_t2(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 submit_burst_nocheck_avx2_t3(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
+submit_burst_nocheck_avx2_t4(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
+IMB_DLL_EXPORT uint32_t
 submit_burst_nocheck_avx512_t1(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 submit_burst_nocheck_avx512_t2(IMB_MGR *state, const uint32_t n_jobs, IMB_JOB **jobs);
@@ -510,16 +508,14 @@ flush_burst_sse_t2(IMB_MGR *state, const uint32_t max_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 flush_burst_sse_t3(IMB_MGR *state, const uint32_t max_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
-flush_burst_avx_t1(IMB_MGR *state, const uint32_t max_jobs, IMB_JOB **jobs);
-IMB_DLL_EXPORT uint32_t
-flush_burst_avx_t2(IMB_MGR *state, const uint32_t max_jobs, IMB_JOB **jobs);
-IMB_DLL_EXPORT uint32_t
 flush_burst_avx2_t1(IMB_MGR *state, const uint32_t max_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 flush_burst_avx2_t2(IMB_MGR *state, const uint32_t max_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 flush_burst_avx2_t3(IMB_MGR *state, const uint32_t max_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
+flush_burst_avx2_t4(IMB_MGR *state, const uint32_t max_jobs, IMB_JOB **jobs);
+IMB_DLL_EXPORT uint32_t
 flush_burst_avx512_t1(IMB_MGR *state, const uint32_t max_jobs, IMB_JOB **jobs);
 IMB_DLL_EXPORT uint32_t
 flush_burst_avx512_t2(IMB_MGR *state, const uint32_t max_jobs, IMB_JOB **jobs);
@@ -537,14 +533,6 @@ submit_cipher_burst_sse_t3(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                            const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
                            const IMB_KEY_SIZE_BYTES key_size);
 IMB_DLL_EXPORT uint32_t
-submit_cipher_burst_avx_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
-                           const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
-                           const IMB_KEY_SIZE_BYTES key_size);
-IMB_DLL_EXPORT uint32_t
-submit_cipher_burst_avx_t2(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
-                           const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
-                           const IMB_KEY_SIZE_BYTES key_size);
-IMB_DLL_EXPORT uint32_t
 submit_cipher_burst_avx2_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                             const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
                             const IMB_KEY_SIZE_BYTES key_size);
@@ -557,6 +545,10 @@ submit_cipher_burst_avx2_t3(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs
                             const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
                             const IMB_KEY_SIZE_BYTES key_size);
 IMB_DLL_EXPORT uint32_t
+submit_cipher_burst_avx2_t4(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                            const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                            const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
 submit_cipher_burst_avx512_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                               const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
                               const IMB_KEY_SIZE_BYTES key_size);
@@ -578,14 +570,6 @@ submit_cipher_burst_nocheck_sse_t3(IMB_MGR *state, IMB_JOB *jobs, const uint32_t
                                    const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
                                    const IMB_KEY_SIZE_BYTES key_size);
 IMB_DLL_EXPORT uint32_t
-submit_cipher_burst_nocheck_avx_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
-                                   const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
-                                   const IMB_KEY_SIZE_BYTES key_size);
-IMB_DLL_EXPORT uint32_t
-submit_cipher_burst_nocheck_avx_t2(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
-                                   const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
-                                   const IMB_KEY_SIZE_BYTES key_size);
-IMB_DLL_EXPORT uint32_t
 submit_cipher_burst_nocheck_avx2_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                                     const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
                                     const IMB_KEY_SIZE_BYTES key_size);
@@ -598,6 +582,10 @@ submit_cipher_burst_nocheck_avx2_t3(IMB_MGR *state, IMB_JOB *jobs, const uint32_
                                     const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
                                     const IMB_KEY_SIZE_BYTES key_size);
 IMB_DLL_EXPORT uint32_t
+submit_cipher_burst_nocheck_avx2_t4(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                                    const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                                    const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
 submit_cipher_burst_nocheck_avx512_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                                       const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
                                       const IMB_KEY_SIZE_BYTES key_size);
@@ -616,12 +604,6 @@ IMB_DLL_EXPORT uint32_t
 submit_hash_burst_sse_t3(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                          const IMB_HASH_ALG hash);
 IMB_DLL_EXPORT uint32_t
-submit_hash_burst_avx_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
-                         const IMB_HASH_ALG hash);
-IMB_DLL_EXPORT uint32_t
-submit_hash_burst_avx_t2(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
-                         const IMB_HASH_ALG hash);
-IMB_DLL_EXPORT uint32_t
 submit_hash_burst_avx2_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                           const IMB_HASH_ALG hash);
 IMB_DLL_EXPORT uint32_t
@@ -631,6 +613,9 @@ IMB_DLL_EXPORT uint32_t
 submit_hash_burst_avx2_t3(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                           const IMB_HASH_ALG hash);
 IMB_DLL_EXPORT uint32_t
+submit_hash_burst_avx2_t4(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                          const IMB_HASH_ALG hash);
+IMB_DLL_EXPORT uint32_t
 submit_hash_burst_avx512_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                             const IMB_HASH_ALG hash);
 IMB_DLL_EXPORT uint32_t
@@ -647,12 +632,6 @@ IMB_DLL_EXPORT uint32_t
 submit_hash_burst_nocheck_sse_t3(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                                  const IMB_HASH_ALG hash);
 IMB_DLL_EXPORT uint32_t
-submit_hash_burst_nocheck_avx_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
-                                 const IMB_HASH_ALG hash);
-IMB_DLL_EXPORT uint32_t
-submit_hash_burst_nocheck_avx_t2(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
-                                 const IMB_HASH_ALG hash);
-IMB_DLL_EXPORT uint32_t
 submit_hash_burst_nocheck_avx2_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                                   const IMB_HASH_ALG hash);
 IMB_DLL_EXPORT uint32_t
@@ -662,12 +641,89 @@ IMB_DLL_EXPORT uint32_t
 submit_hash_burst_nocheck_avx2_t3(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                                   const IMB_HASH_ALG hash);
 IMB_DLL_EXPORT uint32_t
+submit_hash_burst_nocheck_avx2_t4(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                                  const IMB_HASH_ALG hash);
+IMB_DLL_EXPORT uint32_t
 submit_hash_burst_nocheck_avx512_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                                     const IMB_HASH_ALG hash);
 IMB_DLL_EXPORT uint32_t
 submit_hash_burst_nocheck_avx512_t2(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
                                     const IMB_HASH_ALG hash);
 
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_sse_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                         const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                         const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_sse_t2(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                         const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                         const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_sse_t3(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                         const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                         const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_avx2_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                          const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                          const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_avx2_t2(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                          const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                          const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_avx2_t3(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                          const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                          const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_avx2_t4(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                          const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                          const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_avx512_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                            const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                            const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_avx512_t2(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                            const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                            const IMB_KEY_SIZE_BYTES key_size);
+
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_nocheck_sse_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                                 const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                                 const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_nocheck_sse_t2(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                                 const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                                 const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_nocheck_sse_t3(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                                 const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                                 const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_nocheck_avx2_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                                  const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                                  const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_nocheck_avx2_t2(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                                  const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                                  const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_nocheck_avx2_t3(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                                  const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                                  const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_nocheck_avx2_t4(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                                  const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                                  const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_nocheck_avx512_t1(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                                    const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                                    const IMB_KEY_SIZE_BYTES key_size);
+IMB_DLL_EXPORT uint32_t
+submit_aead_burst_nocheck_avx512_t2(IMB_MGR *state, IMB_JOB *jobs, const uint32_t n_jobs,
+                                    const IMB_CIPHER_MODE cipher, const IMB_CIPHER_DIRECTION dir,
+                                    const IMB_KEY_SIZE_BYTES key_size);
+
 /* SSE TYPE1 manager functions */
 IMB_DLL_EXPORT IMB_JOB *
 submit_job_sse_t1(IMB_MGR *state);
@@ -710,34 +766,6 @@ get_next_job_sse_t3(IMB_MGR *state);
 IMB_DLL_EXPORT IMB_JOB *
 get_completed_job_sse_t3(IMB_MGR *state);
 
-/* AVX TYPE1 manager functions */
-IMB_DLL_EXPORT IMB_JOB *
-submit_job_avx_t1(IMB_MGR *state);
-IMB_DLL_EXPORT IMB_JOB *
-flush_job_avx_t1(IMB_MGR *state);
-IMB_DLL_EXPORT uint32_t
-queue_size_avx_t1(IMB_MGR *state);
-IMB_DLL_EXPORT IMB_JOB *
-submit_job_nocheck_avx_t1(IMB_MGR *state);
-IMB_DLL_EXPORT IMB_JOB *
-get_next_job_avx_t1(IMB_MGR *state);
-IMB_DLL_EXPORT IMB_JOB *
-get_completed_job_avx_t1(IMB_MGR *state);
-
-/* AVX TYPE2 manager functions */
-IMB_DLL_EXPORT IMB_JOB *
-submit_job_avx_t2(IMB_MGR *state);
-IMB_DLL_EXPORT IMB_JOB *
-flush_job_avx_t2(IMB_MGR *state);
-IMB_DLL_EXPORT uint32_t
-queue_size_avx_t2(IMB_MGR *state);
-IMB_DLL_EXPORT IMB_JOB *
-submit_job_nocheck_avx_t2(IMB_MGR *state);
-IMB_DLL_EXPORT IMB_JOB *
-get_next_job_avx_t2(IMB_MGR *state);
-IMB_DLL_EXPORT IMB_JOB *
-get_completed_job_avx_t2(IMB_MGR *state);
-
 /* AVX2 TYPE1 manager functions */
 IMB_DLL_EXPORT IMB_JOB *
 submit_job_avx2_t1(IMB_MGR *state);
@@ -780,6 +808,20 @@ get_next_job_avx2_t3(IMB_MGR *state);
 IMB_DLL_EXPORT IMB_JOB *
 get_completed_job_avx2_t3(IMB_MGR *state);
 
+/* AVX2 TYPE4 manager functions */
+IMB_DLL_EXPORT IMB_JOB *
+submit_job_avx2_t4(IMB_MGR *state);
+IMB_DLL_EXPORT IMB_JOB *
+flush_job_avx2_t4(IMB_MGR *state);
+IMB_DLL_EXPORT uint32_t
+queue_size_avx2_t4(IMB_MGR *state);
+IMB_DLL_EXPORT IMB_JOB *
+submit_job_nocheck_avx2_t4(IMB_MGR *state);
+IMB_DLL_EXPORT IMB_JOB *
+get_next_job_avx2_t4(IMB_MGR *state);
+IMB_DLL_EXPORT IMB_JOB *
+get_completed_job_avx2_t4(IMB_MGR *state);
+
 /* AVX512 TYPE1 manager functions */
 IMB_DLL_EXPORT IMB_JOB *
 submit_job_avx512_t1(IMB_MGR *state);
