@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2020-2023, Intel Corporation
+  Copyright (c) 2020-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -36,57 +36,34 @@
 #include "constants.h"
 #include "include/clear_regs_mem.h"
 #include "include/error.h"
+#include "include/arch_sse_type1.h"
+#include "include/arch_sse_type2.h"
+#include "include/arch_avx2_type4.h"
 
-extern void
-sha1_block_sse(const void *, void *);
-extern void
-sha1_block_avx(const void *, void *);
-extern void
-sha1_ni_block_sse(const void *, void *);
-
-extern void
-sha224_block_sse(const void *, void *);
-extern void
-sha224_block_avx(const void *, void *);
-
-extern void
-sha256_block_sse(const void *, void *);
-extern void
-sha256_block_avx(const void *, void *);
-extern void
-sha256_ni_block_sse(const void *, void *);
-
-extern void
-sha384_block_sse(const void *, void *);
-extern void
-sha384_block_avx(const void *, void *);
-
-extern void
-sha512_block_sse(const void *, void *);
-extern void
-sha512_block_avx(const void *, void *);
-
-enum arch_type { ARCH_SSE = 0, ARCH_SSE_SHANI, ARCH_AVX };
+enum arch_type { ARCH_SSE = 0, ARCH_SSE_SHANI, ARCH_AVX, ARCH_AVX2_SHANI };
 
 /* ========================================================================== */
 /*
  * Various utility functions for SHA API
  */
-
 __forceinline uint32_t
 bswap4(const uint32_t val)
 {
-        return ((val >> 24) |             /**< A*/
-                ((val & 0xff0000) >> 8) | /**< B*/
-                ((val & 0xff00) << 8) |   /**< C*/
-                (val << 24));             /**< D*/
+#ifdef LINUX
+        return __builtin_bswap32(val);
+#else
+        return _byteswap_ulong(val);
+#endif
 }
 
 __forceinline uint64_t
 bswap8(const uint64_t val)
 {
-        return (((uint64_t) bswap4((uint32_t) val)) << 32) |
-               (((uint64_t) bswap4((uint32_t) (val >> 32))));
+#ifdef LINUX
+        return __builtin_bswap64(val);
+#else
+        return _byteswap_uint64(val);
+#endif
 }
 
 __forceinline void
@@ -132,37 +109,49 @@ __forceinline void
 sha_generic_one_block(const void *inp, void *digest, const enum arch_type arch, const int sha_type)
 {
         if (sha_type == 1) {
-                if (arch == ARCH_AVX)
-                        sha1_block_avx(inp, digest);
-                else if (arch == ARCH_SSE)
+                IMB_ASSERT(arch != ARCH_AVX2_SHANI);
+                if (arch == ARCH_AVX || arch == ARCH_SSE)
                         sha1_block_sse(inp, digest);
                 else /* arch == ARCH_SSE_SHANI */
                         sha1_ni_block_sse(inp, digest);
         } else if (sha_type == 224) {
-                if (arch == ARCH_AVX)
-                        sha224_block_avx(inp, digest);
-                else if (arch == ARCH_SSE)
+                IMB_ASSERT(arch != ARCH_AVX2_SHANI);
+                if (arch == ARCH_AVX || arch == ARCH_SSE)
                         sha224_block_sse(inp, digest);
                 else /* arch == ARCH_SSE_SHANI */
-                        /* Same as SHA-224 */
                         sha256_ni_block_sse(inp, digest);
         } else if (sha_type == 256) {
-                if (arch == ARCH_AVX)
-                        sha256_block_avx(inp, digest);
-                else if (arch == ARCH_SSE)
+                IMB_ASSERT(arch != ARCH_AVX2_SHANI);
+                if (arch == ARCH_AVX || arch == ARCH_SSE)
                         sha256_block_sse(inp, digest);
                 else /* arch == ARCH_SSE_SHANI */
                         sha256_ni_block_sse(inp, digest);
         } else if (sha_type == 384) {
+                IMB_ASSERT(arch != ARCH_SSE_SHANI);
                 if (arch == ARCH_AVX)
-                        sha384_block_avx(inp, digest);
+                        sha384_block_sse(inp, digest);
+#ifdef SMX_NI
+                else if (arch == ARCH_SSE)
+                        sha384_block_sse(inp, digest);
+                else /* arch == ARCH_AVX2_SHANI */
+                        sha512_ni_block_avx2(inp, digest);
+#else
                 else
                         sha384_block_sse(inp, digest);
+#endif
         } else if (sha_type == 512) {
+                IMB_ASSERT(arch != ARCH_SSE_SHANI);
                 if (arch == ARCH_AVX)
-                        sha512_block_avx(inp, digest);
+                        sha512_block_sse(inp, digest);
+#ifdef SMX_NI
+                else if (arch == ARCH_SSE)
+                        sha512_block_sse(inp, digest);
+                else /* arch == ARCH_AVX2_SHANI */
+                        sha512_ni_block_avx2(inp, digest);
+#else
                 else
                         sha512_block_sse(inp, digest);
+#endif
         }
 }
 
@@ -318,7 +307,7 @@ sha_generic(const void *data, const uint64_t length, void *digest, const enum ar
         clear_mem(cb, sizeof(cb));
         clear_mem(&local_digest, sizeof(local_digest));
         clear_scratch_gps();
-        if (arch == ARCH_AVX)
+        if (arch == ARCH_AVX || arch == ARCH_AVX2_SHANI)
                 clear_scratch_xmms_avx();
         else
                 clear_scratch_xmms_sse();
@@ -343,7 +332,7 @@ sha_generic_1block(const void *data, void *digest, const enum arch_type arch, co
         sha_generic_one_block(data, digest, arch, sha_type);
 #ifdef SAFE_DATA
         clear_scratch_gps();
-        if (arch == ARCH_AVX)
+        if (arch == ARCH_AVX || arch == ARCH_AVX2_SHANI)
                 clear_scratch_xmms_avx();
         else
                 clear_scratch_xmms_sse();
