@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2009-2023, Intel Corporation
+  Copyright (c) 2009-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -58,17 +58,6 @@
 #define ZUC_MIN_BYTELEN 1
 #define ZUC_MAX_BYTELEN (ZUC_MAX_BITLEN / 8)
 
-#ifdef DEBUG
-#ifdef _WIN32
-#define DEBUG_PRINT(_fmt, ...)                                                                     \
-        fprintf(stderr, "%s()::%d " _fmt, __FUNCTION__, __LINE__, __VA_ARGS__)
-#else
-#define DEBUG_PRINT(_fmt, ...) fprintf(stderr, "%s()::%d " _fmt, __func__, __LINE__, __VA_ARGS__)
-#endif
-#else
-#define DEBUG_PRINT(_fmt, ...)
-#endif
-
 /**
  ******************************************************************************
  * @description
@@ -217,9 +206,6 @@ typedef struct zuc_key_16_s {
 IMB_DLL_LOCAL void
 asm_ZucInitialization_sse(const void *pKey, const void *pIv, ZucState_t *pState);
 
-IMB_DLL_LOCAL void
-asm_ZucInitialization_sse_no_aesni(const void *pKey, const void *pIv, ZucState_t *pState);
-
 IMB_DLL_LOCAL void
 asm_ZucInitialization_avx(const void *pKey, const void *pIv, ZucState_t *pState);
 
@@ -247,15 +233,9 @@ asm_ZucInitialization_avx(const void *pKey, const void *pIv, ZucState_t *pState)
 IMB_DLL_LOCAL void
 asm_ZucInitialization_4_sse(ZucKey4_t *pKeys, const uint8_t *ivs, ZucState4_t *pState);
 
-IMB_DLL_LOCAL void
-asm_ZucInitialization_4_sse_no_aesni(ZucKey4_t *pKeys, const uint8_t *ivs, ZucState4_t *pState);
-
 IMB_DLL_LOCAL void
 asm_ZucInitialization_4_gfni_sse(ZucKey4_t *pKeys, const uint8_t *ivs, ZucState4_t *pState);
 
-IMB_DLL_LOCAL void
-asm_ZucInitialization_4_avx(ZucKey4_t *pKeys, const uint8_t *ivs, ZucState4_t *pState);
-
 /**
  ******************************************************************************
  * @description
@@ -289,18 +269,10 @@ IMB_DLL_LOCAL void
 asm_Zuc256Initialization_4_sse(ZucKey4_t *pKeys, const uint8_t *ivs, ZucState4_t *pState,
                                void *tags, const uint64_t tag_sz);
 
-IMB_DLL_LOCAL void
-asm_Zuc256Initialization_4_sse_no_aesni(ZucKey4_t *pKeys, const uint8_t *ivs, ZucState4_t *pState,
-                                        void *tags, const uint64_t tag_sz);
-
 IMB_DLL_LOCAL void
 asm_Zuc256Initialization_4_gfni_sse(ZucKey4_t *pKeys, const uint8_t *ivs, ZucState4_t *pState,
                                     void *tags, const uint64_t tag_sz);
 
-IMB_DLL_LOCAL void
-asm_Zuc256Initialization_4_avx(ZucKey4_t *pKeys, const uint8_t *ivs, ZucState4_t *pState,
-                               void *tags, const uint64_t tag_sz);
-
 /**
  ******************************************************************************
  * @description
@@ -492,9 +464,6 @@ asm_ZucGenKeystream16B_avx(uint32_t *pKeystream, ZucState_t *pState);
 IMB_DLL_LOCAL void
 asm_ZucGenKeystream16B_sse(uint32_t *pKeystream, ZucState_t *pState);
 
-IMB_DLL_LOCAL void
-asm_ZucGenKeystream16B_sse_no_aesni(uint32_t *pKeystream, ZucState_t *pState);
-
 /**
  ******************************************************************************
  *
@@ -517,9 +486,6 @@ asm_ZucGenKeystream16B_sse_no_aesni(uint32_t *pKeystream, ZucState_t *pState);
 IMB_DLL_LOCAL void
 asm_ZucGenKeystream8B_sse(void *pKeystream, ZucState_t *pState);
 
-IMB_DLL_LOCAL void
-asm_ZucGenKeystream8B_sse_no_aesni(void *pKeystream, ZucState_t *pState);
-
 IMB_DLL_LOCAL void
 asm_ZucGenKeystream8B_avx(void *pKeystream, ZucState_t *pState);
 
@@ -549,9 +515,6 @@ asm_ZucGenKeystream8B_avx(void *pKeystream, ZucState_t *pState);
 IMB_DLL_LOCAL void
 asm_ZucGenKeystream_sse(void *pKeystream, ZucState_t *pState, uint64_t numRounds);
 
-IMB_DLL_LOCAL void
-asm_ZucGenKeystream_sse_no_aesni(void *pKeystream, ZucState_t *pState, uint64_t numRounds);
-
 IMB_DLL_LOCAL void
 asm_ZucGenKeystream_avx(void *pKeystream, ZucState_t *pState, uint64_t numRounds);
 
@@ -578,15 +541,9 @@ asm_ZucGenKeystream_avx(void *pKeystream, ZucState_t *pState, uint64_t numRounds
 IMB_DLL_LOCAL void
 asm_ZucGenKeystream16B_4_sse(ZucState4_t *pState, uint32_t *pKeyStr[4]);
 
-IMB_DLL_LOCAL void
-asm_ZucGenKeystream16B_4_sse_no_aesni(ZucState4_t *pState, uint32_t *pKeyStr[4]);
-
 IMB_DLL_LOCAL void
 asm_ZucGenKeystream16B_4_gfni_sse(ZucState4_t *pState, uint32_t *pKeyStr[4]);
 
-IMB_DLL_LOCAL void
-asm_ZucGenKeystream16B_4_avx(ZucState4_t *pState, uint32_t *pKeyStr[4]);
-
 /**
  ******************************************************************************
  *
@@ -765,15 +722,9 @@ asm_ZucGenKeystream64B_16_skip4_gfni_avx512(ZucState16_t *pState, uint32_t *pKey
 IMB_DLL_LOCAL void
 asm_ZucGenKeystream8B_4_sse(ZucState4_t *pState, uint32_t *pKeyStr[4]);
 
-IMB_DLL_LOCAL void
-asm_ZucGenKeystream8B_4_sse_no_aesni(ZucState4_t *pState, uint32_t *pKeyStr[4]);
-
 IMB_DLL_LOCAL void
 asm_ZucGenKeystream8B_4_gfni_sse(ZucState4_t *pState, uint32_t *pKeyStr[4]);
 
-IMB_DLL_LOCAL void
-asm_ZucGenKeystream8B_4_avx(ZucState4_t *pState, uint32_t *pKeyStr[4]);
-
 /**
  ******************************************************************************
  *
@@ -797,15 +748,9 @@ asm_ZucGenKeystream8B_4_avx(ZucState4_t *pState, uint32_t *pKeyStr[4]);
 IMB_DLL_LOCAL void
 asm_ZucGenKeystream4B_4_sse(ZucState4_t *pState, uint32_t *pKeyStr[4]);
 
-IMB_DLL_LOCAL void
-asm_ZucGenKeystream4B_4_sse_no_aesni(ZucState4_t *pState, uint32_t *pKeyStr[4]);
-
 IMB_DLL_LOCAL void
 asm_ZucGenKeystream4B_4_gfni_sse(ZucState4_t *pState, uint32_t *pKeyStr[4]);
 
-IMB_DLL_LOCAL void
-asm_ZucGenKeystream4B_4_avx(ZucState4_t *pState, uint32_t *pKeyStr[4]);
-
 /**
  ******************************************************************************
  *
@@ -1080,18 +1025,10 @@ IMB_DLL_LOCAL void
 asm_ZucCipher_4_sse(ZucState4_t *pState, const uint64_t *pIn[4], uint64_t *pOut[4],
                     uint16_t lengths[4], const uint64_t minLength);
 
-IMB_DLL_LOCAL void
-asm_ZucCipher_4_sse_no_aesni(ZucState4_t *pState, const uint64_t *pIn[4], uint64_t *pOut[4],
-                             uint16_t lengths[4], const uint64_t minLength);
-
 IMB_DLL_LOCAL void
 asm_ZucCipher_4_gfni_sse(ZucState4_t *pState, const uint64_t *pIn[4], uint64_t *pOut[4],
                          uint16_t lengths[4], const uint64_t minLength);
 
-IMB_DLL_LOCAL void
-asm_ZucCipher_4_avx(ZucState4_t *pState, const uint64_t *pIn[4], uint64_t *pOut[4],
-                    uint16_t lengths[4], const uint64_t minLength);
-
 /**
  ******************************************************************************
  *
@@ -1177,15 +1114,9 @@ asm_ZucCipher_16_gfni_avx512(ZucState16_t *pState, const uint64_t *pIn[16], uint
 IMB_DLL_LOCAL void
 asm_Eia3Round16B_sse(void *T, const void *ks, const void *data, const uint64_t tag_sz);
 
-IMB_DLL_LOCAL void
-asm_Eia3Round16B_sse_no_aesni(void *T, const void *ks, const void *data, const uint64_t tag_sz);
-
 IMB_DLL_LOCAL void
 asm_Eia3Round16B_gfni_sse(void *T, const void *ks, const void *data, const uint64_t tag_sz);
 
-IMB_DLL_LOCAL void
-asm_Eia3Round16B_avx(void *T, const void *ks, const void *data, const uint64_t tag_sz);
-
 IMB_DLL_LOCAL void
 asm_Eia3Round32B_avx(void *T, const void *ks, const void *data, const uint64_t tag_sz);
 
@@ -1209,10 +1140,6 @@ IMB_DLL_LOCAL void
 asm_Eia3Remainder_sse(void *T, const void *ks, const void *data, const uint64_t n_bits,
                       const uint64_t key_size, const uint64_t tag_size);
 
-IMB_DLL_LOCAL void
-asm_Eia3Remainder_sse_no_aesni(void *T, const void *ks, const void *data, const uint64_t n_bits,
-                               const uint64_t key_size, const uint64_t tag_size);
-
 IMB_DLL_LOCAL void
 asm_Eia3Remainder_gfni_sse(void *T, const void *ks, const void *data, const uint64_t n_bits,
                            const uint64_t key_size, const uint64_t tag_size);
@@ -1326,13 +1253,6 @@ zuc_eia3_4_buffer_job_no_gfni_sse(const void *const pKey[4], const uint8_t *ivs,
                                   const void *const pBufferIn[4], uint32_t *pMacI[4],
                                   const uint16_t lengthInBits[4], const void *const job_in_lane[4]);
 
-IMB_DLL_LOCAL
-void
-zuc_eia3_4_buffer_job_sse_no_aesni(const void *const pKey[4], const uint8_t *ivs,
-                                   const void *const pBufferIn[4], uint32_t *pMacI[4],
-                                   const uint16_t lengthInBits[4],
-                                   const void *const job_in_lane[4]);
-
 IMB_DLL_LOCAL
 void
 zuc256_eia3_4_buffer_job_gfni_sse(const void *const pKey[4], const uint8_t *ivs,
@@ -1347,26 +1267,6 @@ zuc256_eia3_4_buffer_job_no_gfni_sse(const void *const pKey[4], const uint8_t *i
                                      const uint16_t lengthInBits[4],
                                      const void *const job_in_lane[4], const uint64_t tag_size);
 
-IMB_DLL_LOCAL
-void
-zuc256_eia3_4_buffer_job_sse_no_aesni(const void *const pKey[4], const uint8_t *ivs,
-                                      const void *const pBufferIn[4], void *pMacI[4],
-                                      const uint16_t lengthInBits[4],
-                                      const void *const job_in_lane[4], const uint64_t tag_size);
-
-IMB_DLL_LOCAL
-void
-zuc_eia3_4_buffer_job_avx(const void *const pKey[4], const uint8_t *ivs,
-                          const void *const pBufferIn[4], uint32_t *pMacI[4],
-                          const uint16_t lengthInBits[4], const void *const job_in_lane[4]);
-
-IMB_DLL_LOCAL
-void
-zuc256_eia3_4_buffer_job_avx(const void *const pKey[4], const uint8_t *ivs,
-                             const void *const pBufferIn[4], void *pMacI[4],
-                             const uint16_t lengthInBits[4], const void *const job_in_lane[4],
-                             const uint64_t tag_size);
-
 IMB_DLL_LOCAL
 void
 zuc_eia3_8_buffer_job_avx2(const void *const pKey[8], const uint8_t *ivs,
@@ -1424,20 +1324,6 @@ zuc_eia3_n_buffer_gfni_sse(const void *const pKey[], const void *const pIv[],
                            const void *const pBufferIn[], const uint32_t lengthInBits[],
                            uint32_t *pMacI[], const uint32_t numBuffers);
 
-void
-zuc_eea3_1_buffer_sse_no_aesni(const void *pKey, const void *pIv, const void *pBufferIn,
-                               void *pBufferOut, const uint32_t lengthInBytes);
-
-void
-zuc_eea3_4_buffer_sse_no_aesni(const void *const pKey[4], const void *const pIv[4],
-                               const void *const pBufferIn[4], void *pBufferOut[4],
-                               const uint32_t lengthInBytes[4]);
-
-void
-zuc_eea3_n_buffer_sse_no_aesni(const void *const pKey[], const void *const pIv[],
-                               const void *const pBufferIn[], void *pBufferOut[],
-                               const uint32_t lengthInBytes[], const uint32_t numBuffers);
-
 void
 zuc_eea3_4_buffer_gfni_sse(const void *const pKey[4], const void *const pIv[4],
                            const void *const pBufferIn[4], void *pBufferOut[4],
@@ -1448,38 +1334,6 @@ zuc_eea3_n_buffer_gfni_sse(const void *const pKey[], const void *const pIv[],
                            const void *const pBufferIn[], void *pBufferOut[],
                            const uint32_t lengthInBytes[], const uint32_t numBuffers);
 
-void
-zuc_eia3_1_buffer_sse_no_aesni(const void *pKey, const void *pIv, const void *pBufferIn,
-                               const uint32_t lengthInBits, uint32_t *pMacI);
-
-void
-zuc_eia3_n_buffer_sse_no_aesni(const void *const pKey[], const void *const pIv[],
-                               const void *const pBufferIn[], const uint32_t lengthInBits[],
-                               uint32_t *pMacI[], const uint32_t numBuffers);
-
-void
-zuc_eea3_1_buffer_avx(const void *pKey, const void *pIv, const void *pBufferIn, void *pBufferOut,
-                      const uint32_t lengthInBytes);
-
-void
-zuc_eea3_4_buffer_avx(const void *const pKey[4], const void *const pIv[4],
-                      const void *const pBufferIn[4], void *pBufferOut[4],
-                      const uint32_t lengthInBytes[4]);
-
-void
-zuc_eea3_n_buffer_avx(const void *const pKey[], const void *const pIv[],
-                      const void *const pBufferIn[], void *pBufferOut[],
-                      const uint32_t lengthInBytes[], const uint32_t numBuffers);
-
-void
-zuc_eia3_1_buffer_avx(const void *pKey, const void *pIv, const void *pBufferIn,
-                      const uint32_t lengthInBits, uint32_t *pMacI);
-
-void
-zuc_eia3_n_buffer_avx(const void *const pKey[], const void *const pIv[],
-                      const void *const pBufferIn[], const uint32_t lengthInBits[],
-                      uint32_t *pMacI[], const uint32_t numBuffers);
-
 void
 zuc_eea3_1_buffer_avx2(const void *pKey, const void *pIv, const void *pBufferIn, void *pBufferOut,
                        const uint32_t lengthInBytes);
@@ -1529,15 +1383,15 @@ zuc_eia3_n_buffer_gfni_avx512(const void *const pKey[], const void *const pIv[],
 /* Internal API */
 IMB_DLL_LOCAL
 void
-_zuc_eea3_4_buffer_avx(const void *const pKey[4], const void *const pIv[4],
+_zuc_eea3_4_buffer_sse(const void *const pKey[4], const void *const pIv[4],
                        const void *const pBufferIn[4], void *pBufferOut[4],
-                       const uint32_t length[4]);
+                       const uint32_t length[4], const unsigned use_gfni);
 
 IMB_DLL_LOCAL
 void
-_zuc_eia3_4_buffer_avx(const void *const pKey[4], const void *const pIv[4],
+_zuc_eia3_4_buffer_sse(const void *const pKey[4], const void *const pIv[4],
                        const void *const pBufferIn[4], const uint32_t lengthInBits[4],
-                       uint32_t *pMacI[4]);
+                       uint32_t *pMacI[4], const unsigned use_gfni);
 
 IMB_DLL_LOCAL
 void
