@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2012-2023, Intel Corporation
+  Copyright (c) 2012-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -29,7 +29,6 @@
 #include "include/ipsec_ooo_mgr.h"
 #include "include/error.h"
 #include "include/cpu_feature.h"
-#include "include/aesni_emu.h"
 #include "include/arch_x86_64.h"
 
 IMB_DLL_LOCAL void
@@ -42,8 +41,9 @@ init_mb_mgr_sse_internal(IMB_MGR *state, const int reset_mgrs)
         }
 #endif
 
-        if (!(state->features & IMB_FEATURE_AESNI)) {
-                fallback_no_aesni(state, 1);
+        /* Check minimum CPU flags needed for SSE interface */
+        if ((state->features & IMB_CPUFLAGS_SSE) != IMB_CPUFLAGS_SSE) {
+                imb_set_errno(state, IMB_ERR_MISSING_CPUFLAGS_INIT_MGR);
                 return;
         }
 
