@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2022-2023, Intel Corporation
+  Copyright (c) 2022-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -101,7 +101,7 @@ IMB_JOB *
 submit_job_sha384_sse(MB_MGR_SHA_512_OOO *state, IMB_JOB *job)
 {
         return submit_flush_job_sha_512(state, job, 2, 1, 384, IMB_SHA_512_BLOCK_SIZE,
-                                        SHA384_PAD_SIZE, call_sha512_x2_sse_from_c);
+                                        SHA384_PAD_SIZE, call_sha512_x2_sse_from_c, 0);
 }
 
 IMB_DLL_LOCAL
@@ -109,7 +109,7 @@ IMB_JOB *
 flush_job_sha384_sse(MB_MGR_SHA_512_OOO *state, IMB_JOB *job)
 {
         return submit_flush_job_sha_512(state, job, 2, 0, 384, IMB_SHA_512_BLOCK_SIZE,
-                                        SHA384_PAD_SIZE, call_sha512_x2_sse_from_c);
+                                        SHA384_PAD_SIZE, call_sha512_x2_sse_from_c, 0);
 }
 
 /* ========================================================================== */
@@ -122,7 +122,7 @@ IMB_JOB *
 submit_job_sha512_sse(MB_MGR_SHA_512_OOO *state, IMB_JOB *job)
 {
         return submit_flush_job_sha_512(state, job, 2, 1, 512, IMB_SHA_512_BLOCK_SIZE,
-                                        SHA512_PAD_SIZE, call_sha512_x2_sse_from_c);
+                                        SHA512_PAD_SIZE, call_sha512_x2_sse_from_c, 0);
 }
 
 IMB_DLL_LOCAL
@@ -130,5 +130,5 @@ IMB_JOB *
 flush_job_sha512_sse(MB_MGR_SHA_512_OOO *state, IMB_JOB *job)
 {
         return submit_flush_job_sha_512(state, job, 2, 0, 512, IMB_SHA_512_BLOCK_SIZE,
-                                        SHA512_PAD_SIZE, call_sha512_x2_sse_from_c);
+                                        SHA512_PAD_SIZE, call_sha512_x2_sse_from_c, 0);
 }
