@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2022-2023, Intel Corporation
+  Copyright (c) 2022-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -43,8 +43,6 @@
 #include "include/save_xmms.h"
 #include "include/des.h"
 #include "include/cpu_feature.h"
-#include "include/noaesni.h"
-#include "include/aesni_emu.h"
 #include "include/error.h"
 
 #include "include/arch_sse_type1.h"
@@ -70,6 +68,8 @@
 #define SUBMIT_CIPHER_BURST_NOCHECK submit_cipher_burst_nocheck_sse_t2
 #define SUBMIT_HASH_BURST           submit_hash_burst_sse_t2
 #define SUBMIT_HASH_BURST_NOCHECK   submit_hash_burst_nocheck_sse_t2
+#define SUBMIT_AEAD_BURST           submit_aead_burst_sse_t2
+#define SUBMIT_AEAD_BURST_NOCHECK   submit_aead_burst_nocheck_sse_t2
 #define SET_SUITE_ID_FN             set_suite_id_sse_t2
 
 /* Hash */
@@ -93,21 +93,21 @@
 #define SUBMIT_JOB_AES_GCM_ENC submit_job_aes_gcm_enc_sse
 
 /* AES-CBC */
-#define SUBMIT_JOB_AES_CBC_128_ENC submit_job_aes128_enc_sse
+#define SUBMIT_JOB_AES_CBC_128_ENC submit_job_aes128_enc_x8_sse
 #define SUBMIT_JOB_AES_CBC_128_DEC submit_job_aes128_dec_sse
-#define FLUSH_JOB_AES_CBC_128_ENC  flush_job_aes128_enc_sse
+#define FLUSH_JOB_AES_CBC_128_ENC  flush_job_aes128_enc_x8_sse
 
-#define SUBMIT_JOB_AES_CBC_192_ENC submit_job_aes192_enc_sse
+#define SUBMIT_JOB_AES_CBC_192_ENC submit_job_aes192_enc_x8_sse
 #define SUBMIT_JOB_AES_CBC_192_DEC submit_job_aes192_dec_sse
-#define FLUSH_JOB_AES_CBC_192_ENC  flush_job_aes192_enc_sse
+#define FLUSH_JOB_AES_CBC_192_ENC  flush_job_aes192_enc_x8_sse
 
-#define SUBMIT_JOB_AES_CBC_256_ENC submit_job_aes256_enc_sse
+#define SUBMIT_JOB_AES_CBC_256_ENC submit_job_aes256_enc_x8_sse
 #define SUBMIT_JOB_AES_CBC_256_DEC submit_job_aes256_dec_sse
-#define FLUSH_JOB_AES_CBC_256_ENC  flush_job_aes256_enc_sse
+#define FLUSH_JOB_AES_CBC_256_ENC  flush_job_aes256_enc_x8_sse
 
-#define AES_CBC_DEC_128 aes_cbc_dec_128_sse
-#define AES_CBC_DEC_192 aes_cbc_dec_192_sse
-#define AES_CBC_DEC_256 aes_cbc_dec_256_sse
+#define AES_CBC_DEC_128 aes_cbc_dec_128_by8_sse
+#define AES_CBC_DEC_192 aes_cbc_dec_192_by8_sse
+#define AES_CBC_DEC_256 aes_cbc_dec_256_by8_sse
 
 /* AES-CBCS */
 #define SUBMIT_JOB_AES128_CBCS_1_9_ENC submit_job_aes128_cbcs_1_9_enc_sse
@@ -123,12 +123,12 @@
 #define SUBMIT_JOB_AES_ECB_256_ENC submit_job_aes_ecb_256_enc_sse
 #define SUBMIT_JOB_AES_ECB_256_DEC submit_job_aes_ecb_256_dec_sse
 
-#define AES_ECB_ENC_128 aes_ecb_enc_128_by4_sse
-#define AES_ECB_ENC_192 aes_ecb_enc_192_by4_sse
-#define AES_ECB_ENC_256 aes_ecb_enc_256_by4_sse
-#define AES_ECB_DEC_128 aes_ecb_dec_128_by4_sse
-#define AES_ECB_DEC_192 aes_ecb_dec_192_by4_sse
-#define AES_ECB_DEC_256 aes_ecb_dec_256_by4_sse
+#define AES_ECB_ENC_128 aes_ecb_enc_128_by8_sse
+#define AES_ECB_ENC_192 aes_ecb_enc_192_by8_sse
+#define AES_ECB_ENC_256 aes_ecb_enc_256_by8_sse
+#define AES_ECB_DEC_128 aes_ecb_dec_128_by8_sse
+#define AES_ECB_DEC_192 aes_ecb_dec_192_by8_sse
+#define AES_ECB_DEC_256 aes_ecb_dec_256_by8_sse
 
 /* AES-CTR */
 #define AES_CTR_128     aes_cntr_128_sse
@@ -142,23 +142,32 @@
 #define AES_CNTR_CCM_128 aes_cntr_ccm_128_sse
 #define AES_CNTR_CCM_256 aes_cntr_ccm_256_sse
 
-#define FLUSH_JOB_AES128_CCM_AUTH  flush_job_aes128_ccm_auth_sse
-#define SUBMIT_JOB_AES128_CCM_AUTH submit_job_aes128_ccm_auth_sse
+#define FLUSH_JOB_AES128_CCM_AUTH  flush_job_aes128_ccm_auth_x8_sse
+#define SUBMIT_JOB_AES128_CCM_AUTH submit_job_aes128_ccm_auth_x8_sse
 
-#define FLUSH_JOB_AES256_CCM_AUTH  flush_job_aes256_ccm_auth_sse
-#define SUBMIT_JOB_AES256_CCM_AUTH submit_job_aes256_ccm_auth_sse
+#define FLUSH_JOB_AES256_CCM_AUTH  flush_job_aes256_ccm_auth_x8_sse
+#define SUBMIT_JOB_AES256_CCM_AUTH submit_job_aes256_ccm_auth_x8_sse
 
 /* AES-CMAC */
-#define FLUSH_JOB_AES128_CMAC_AUTH  flush_job_aes128_cmac_auth_sse
-#define SUBMIT_JOB_AES128_CMAC_AUTH submit_job_aes128_cmac_auth_sse
+#define FLUSH_JOB_AES128_CMAC_AUTH  flush_job_aes128_cmac_auth_x8_sse
+#define SUBMIT_JOB_AES128_CMAC_AUTH submit_job_aes128_cmac_auth_x8_sse
 
-#define FLUSH_JOB_AES256_CMAC_AUTH  flush_job_aes256_cmac_auth_sse
-#define SUBMIT_JOB_AES256_CMAC_AUTH submit_job_aes256_cmac_auth_sse
+#define FLUSH_JOB_AES256_CMAC_AUTH  flush_job_aes256_cmac_auth_x8_sse
+#define SUBMIT_JOB_AES256_CMAC_AUTH submit_job_aes256_cmac_auth_x8_sse
 
-/* AES-CFB */
+/* AES-CFB ONE BLOCK*/
 #define AES_CFB_128_ONE aes_cfb_128_one_sse
 #define AES_CFB_256_ONE aes_cfb_256_one_sse
 
+/* AES-CFB */
+#define AES_CFB_128_ENC aes_cfb_128_enc_sse
+#define AES_CFB_192_ENC aes_cfb_192_enc_sse
+#define AES_CFB_256_ENC aes_cfb_256_enc_sse
+
+#define AES_CFB_128_DEC aes_cfb_128_dec_sse
+#define AES_CFB_192_DEC aes_cfb_192_dec_sse
+#define AES_CFB_256_DEC aes_cfb_256_dec_sse
+
 /* AES-XCBC */
 #define SUBMIT_JOB_AES_XCBC submit_job_aes_xcbc_sse
 #define FLUSH_JOB_AES_XCBC  flush_job_aes_xcbc_sse
@@ -256,6 +265,13 @@ flush_snow3g_uea2_job_sse(IMB_MGR *state)
 #define SM4_ECB     sm4_ecb_sse
 #define SM4_CBC_ENC sm4_cbc_enc_sse
 #define SM4_CBC_DEC sm4_cbc_dec_sse
+#define SM4_CTR     sm4_ctr_sse
+
+/* SM3 */
+#define SUBMIT_JOB_SM3      sm3_msg_submit_sse
+#define FLUSH_JOB_SM3       unused
+#define SUBMIT_JOB_HMAC_SM3 sm3_hmac_submit_sse
+#define FLUSH_JOB_HMAC_SM3  unused
 
 /* ====================================================================== */
 
@@ -263,15 +279,15 @@ static void
 reset_ooo_mgrs(IMB_MGR *state)
 {
         /* Init AES out-of-order fields */
-        ooo_mgr_aes_reset(state->aes128_ooo, 4);
-        ooo_mgr_aes_reset(state->aes192_ooo, 4);
-        ooo_mgr_aes_reset(state->aes256_ooo, 4);
+        ooo_mgr_aes_reset(state->aes128_ooo, 8);
+        ooo_mgr_aes_reset(state->aes192_ooo, 8);
+        ooo_mgr_aes_reset(state->aes256_ooo, 8);
 
         /* DOCSIS SEC BPI uses same settings as AES CBC */
-        ooo_mgr_docsis_aes_reset(state->docsis128_sec_ooo, 4);
-        ooo_mgr_docsis_aes_reset(state->docsis128_crc32_sec_ooo, 4);
-        ooo_mgr_docsis_aes_reset(state->docsis256_sec_ooo, 4);
-        ooo_mgr_docsis_aes_reset(state->docsis256_crc32_sec_ooo, 4);
+        ooo_mgr_docsis_aes_reset(state->docsis128_sec_ooo, 8);
+        ooo_mgr_docsis_aes_reset(state->docsis128_crc32_sec_ooo, 8);
+        ooo_mgr_docsis_aes_reset(state->docsis256_sec_ooo, 8);
+        ooo_mgr_docsis_aes_reset(state->docsis256_crc32_sec_ooo, 8);
 
         /* Init ZUC out-of-order fields */
         ooo_mgr_zuc_reset(state->zuc_eea3_ooo, 4);
@@ -303,12 +319,12 @@ reset_ooo_mgrs(IMB_MGR *state)
         ooo_mgr_aes_xcbc_reset(state->aes_xcbc_ooo, 4);
 
         /* Init AES-CCM auth out-of-order fields */
-        ooo_mgr_ccm_reset(state->aes_ccm_ooo, 4);
-        ooo_mgr_ccm_reset(state->aes256_ccm_ooo, 4);
+        ooo_mgr_ccm_reset(state->aes_ccm_ooo, 8);
+        ooo_mgr_ccm_reset(state->aes256_ccm_ooo, 8);
 
         /* Init AES-CMAC auth out-of-order fields */
-        ooo_mgr_cmac_reset(state->aes_cmac_ooo, 4);
-        ooo_mgr_cmac_reset(state->aes256_cmac_ooo, 4);
+        ooo_mgr_cmac_reset(state->aes_cmac_ooo, 8);
+        ooo_mgr_cmac_reset(state->aes256_cmac_ooo, 8);
 
         /* Init AES-CBCS out-of-order fields */
         ooo_mgr_aes_reset(state->aes128_cbcs_ooo, 4);
@@ -333,6 +349,11 @@ reset_ooo_mgrs(IMB_MGR *state)
 
         /* Init SNOW3G-UIA out-of-order fields */
         ooo_mgr_snow3g_reset(state->snow3g_uia2_ooo, 4);
+
+        /*  Init AES-CFB out-of-order fields */
+        ooo_mgr_aes_reset(state->aes_cfb_128_ooo, 1);
+        ooo_mgr_aes_reset(state->aes_cfb_192_ooo, 1);
+        ooo_mgr_aes_reset(state->aes_cfb_256_ooo, 1);
 }
 
 IMB_DLL_LOCAL void
@@ -347,6 +368,9 @@ init_mb_mgr_sse_t2_internal(IMB_MGR *state, const int reset_mgrs)
         /* Set architecture for future checks */
         state->used_arch = (uint32_t) IMB_ARCH_SSE;
 
+        /* Set architecture type for future checks */
+        state->used_arch_type = 2;
+
         if (reset_mgrs) {
                 reset_ooo_mgrs(state);
 
@@ -370,6 +394,8 @@ init_mb_mgr_sse_t2_internal(IMB_MGR *state, const int reset_mgrs)
         state->submit_cipher_burst_nocheck = SUBMIT_CIPHER_BURST_NOCHECK;
         state->submit_hash_burst = SUBMIT_HASH_BURST;
         state->submit_hash_burst_nocheck = SUBMIT_HASH_BURST_NOCHECK;
+        state->submit_aead_burst = SUBMIT_AEAD_BURST;
+        state->submit_aead_burst_nocheck = SUBMIT_AEAD_BURST_NOCHECK;
         state->set_suite_id = SET_SUITE_ID_FN;
 
         state->keyexp_128 = aes_keyexp_128_sse;
