@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2022-2023, Intel Corporation
+  Copyright (c) 2022-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -43,8 +43,6 @@
 #include "include/save_xmms.h"
 #include "include/des.h"
 #include "include/cpu_feature.h"
-#include "include/noaesni.h"
-#include "include/aesni_emu.h"
 #include "include/error.h"
 
 #include "include/arch_sse_type1.h"
@@ -71,6 +69,8 @@
 #define SUBMIT_CIPHER_BURST_NOCHECK submit_cipher_burst_nocheck_sse_t3
 #define SUBMIT_HASH_BURST           submit_hash_burst_sse_t3
 #define SUBMIT_HASH_BURST_NOCHECK   submit_hash_burst_nocheck_sse_t3
+#define SUBMIT_AEAD_BURST           submit_aead_burst_sse_t3
+#define SUBMIT_AEAD_BURST_NOCHECK   submit_aead_burst_nocheck_sse_t3
 #define SET_SUITE_ID_FN             set_suite_id_sse_t3
 
 /* Hash */
@@ -156,10 +156,19 @@
 #define FLUSH_JOB_AES256_CMAC_AUTH  flush_job_aes256_cmac_auth_x8_sse
 #define SUBMIT_JOB_AES256_CMAC_AUTH submit_job_aes256_cmac_auth_x8_sse
 
-/* AES-CFB */
+/* AES-CFB ONE BLOCK*/
 #define AES_CFB_128_ONE aes_cfb_128_one_sse
 #define AES_CFB_256_ONE aes_cfb_256_one_sse
 
+/* AES-CFB */
+#define AES_CFB_128_ENC aes_cfb_128_enc_sse
+#define AES_CFB_192_ENC aes_cfb_192_enc_sse
+#define AES_CFB_256_ENC aes_cfb_256_enc_sse
+
+#define AES_CFB_128_DEC aes_cfb_128_dec_sse
+#define AES_CFB_192_DEC aes_cfb_192_dec_sse
+#define AES_CFB_256_DEC aes_cfb_256_dec_sse
+
 /* AES-XCBC */
 #define SUBMIT_JOB_AES_XCBC submit_job_aes_xcbc_sse
 #define FLUSH_JOB_AES_XCBC  flush_job_aes_xcbc_sse
@@ -257,6 +266,13 @@ flush_snow3g_uea2_job_sse(IMB_MGR *state)
 #define SM4_ECB     sm4_ecb_sse
 #define SM4_CBC_ENC sm4_cbc_enc_sse
 #define SM4_CBC_DEC sm4_cbc_dec_sse
+#define SM4_CTR     sm4_ctr_sse
+
+/* SM3 */
+#define SUBMIT_JOB_SM3      sm3_msg_submit_sse
+#define FLUSH_JOB_SM3       unused
+#define SUBMIT_JOB_HMAC_SM3 sm3_hmac_submit_sse
+#define FLUSH_JOB_HMAC_SM3  unused
 
 /* ====================================================================== */
 
@@ -334,6 +350,11 @@ reset_ooo_mgrs(IMB_MGR *state)
 
         /* Init SNOW3G-UIA out-of-order fields */
         ooo_mgr_snow3g_reset(state->snow3g_uia2_ooo, 4);
+
+        /*  Init AES-CFB out-of-order fields */
+        ooo_mgr_aes_reset(state->aes_cfb_128_ooo, 1);
+        ooo_mgr_aes_reset(state->aes_cfb_192_ooo, 1);
+        ooo_mgr_aes_reset(state->aes_cfb_256_ooo, 1);
 }
 
 IMB_DLL_LOCAL void
@@ -348,6 +369,9 @@ init_mb_mgr_sse_t3_internal(IMB_MGR *state, const int reset_mgrs)
         /* Set architecture for future checks */
         state->used_arch = (uint32_t) IMB_ARCH_SSE;
 
+        /* Set architecture type for future checks */
+        state->used_arch_type = 3;
+
         if (reset_mgrs) {
                 reset_ooo_mgrs(state);
 
@@ -371,6 +395,8 @@ init_mb_mgr_sse_t3_internal(IMB_MGR *state, const int reset_mgrs)
         state->submit_cipher_burst_nocheck = SUBMIT_CIPHER_BURST_NOCHECK;
         state->submit_hash_burst = SUBMIT_HASH_BURST;
         state->submit_hash_burst_nocheck = SUBMIT_HASH_BURST_NOCHECK;
+        state->submit_aead_burst = SUBMIT_AEAD_BURST;
+        state->submit_aead_burst_nocheck = SUBMIT_AEAD_BURST_NOCHECK;
         state->set_suite_id = SET_SUITE_ID_FN;
 
         state->keyexp_128 = aes_keyexp_128_sse;
