@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2020-2023, Intel Corporation
+  Copyright (c) 2020-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -53,8 +53,6 @@ chacha20_enc_dec_ks(const void *src, void *dst, const uint64_t length, const voi
 {
         if (arch == IMB_ARCH_SSE)
                 chacha20_enc_dec_ks_sse(src, dst, length, key, ctx);
-        else if (arch == IMB_ARCH_AVX)
-                chacha20_enc_dec_ks_avx(src, dst, length, key, ctx);
         else if (arch == IMB_ARCH_AVX2)
                 chacha20_enc_dec_ks_avx2(src, dst, length, key, ctx);
         else /* IMB_ARCH_AVX512 */
@@ -525,10 +523,6 @@ aead_chacha20_poly1305(IMB_JOB *job, const IMB_ARCH arch, const unsigned ifma)
                 case IMB_ARCH_SSE:
                         submit_job_chacha20_poly_enc_sse(job, ks);
                         break;
-                case IMB_ARCH_AVX:
-                        submit_job_chacha20_enc_dec_avx(job);
-                        poly1305_key_gen_avx(job->enc_keys, job->iv, ks);
-                        break;
                 case IMB_ARCH_AVX2:
                         submit_job_chacha20_enc_dec_avx2(job);
                         poly1305_key_gen_avx(job->enc_keys, job->iv, ks);
@@ -552,7 +546,6 @@ aead_chacha20_poly1305(IMB_JOB *job, const IMB_ARCH arch, const unsigned ifma)
                         len_to_gen = (cipher_len >= (256 - 64)) ? 256 : (cipher_len + 64);
                         gen_keystr_poly_key_sse(job->enc_keys, job->iv, len_to_gen, ks);
                         break;
-                case IMB_ARCH_AVX:
                 case IMB_ARCH_AVX2:
                         poly1305_key_gen_avx(job->enc_keys, job->iv, ks);
                         break;
@@ -573,9 +566,6 @@ aead_chacha20_poly1305(IMB_JOB *job, const IMB_ARCH arch, const unsigned ifma)
                 case IMB_ARCH_SSE:
                         submit_job_chacha20_poly_dec_sse(job, ks + 64, len_to_gen - 64);
                         break;
-                case IMB_ARCH_AVX:
-                        submit_job_chacha20_enc_dec_avx(job);
-                        break;
                 case IMB_ARCH_AVX2:
                         submit_job_chacha20_enc_dec_avx2(job);
                         break;
@@ -612,14 +602,6 @@ aead_chacha20_poly1305_sse(IMB_MGR *mgr, IMB_JOB *job)
         return aead_chacha20_poly1305(job, IMB_ARCH_SSE, 0);
 }
 
-IMB_DLL_LOCAL
-IMB_JOB *
-aead_chacha20_poly1305_avx(IMB_MGR *mgr, IMB_JOB *job)
-{
-        (void) mgr;
-        return aead_chacha20_poly1305(job, IMB_ARCH_AVX, 0);
-}
-
 IMB_DLL_LOCAL
 IMB_JOB *
 aead_chacha20_poly1305_avx2(IMB_MGR *mgr, IMB_JOB *job)
@@ -648,14 +630,6 @@ aead_chacha20_poly1305_sgl_sse(IMB_MGR *mgr, IMB_JOB *job)
         return aead_chacha20_poly1305_sgl(job, IMB_ARCH_SSE, 0);
 }
 
-IMB_DLL_LOCAL
-IMB_JOB *
-aead_chacha20_poly1305_sgl_avx(IMB_MGR *mgr, IMB_JOB *job)
-{
-        (void) mgr;
-        return aead_chacha20_poly1305_sgl(job, IMB_ARCH_AVX, 0);
-}
-
 IMB_DLL_LOCAL
 IMB_JOB *
 aead_chacha20_poly1305_sgl_avx2(IMB_MGR *mgr, IMB_JOB *job)
@@ -684,14 +658,6 @@ init_chacha20_poly1305_sse(const void *key, struct chacha20_poly1305_context_dat
         init_chacha20_poly1305_direct(key, ctx, iv, aad, aad_len, IMB_ARCH_SSE, 1, 0);
 }
 
-IMB_DLL_LOCAL
-void
-init_chacha20_poly1305_avx(const void *key, struct chacha20_poly1305_context_data *ctx,
-                           const void *iv, const void *aad, const uint64_t aad_len)
-{
-        init_chacha20_poly1305_direct(key, ctx, iv, aad, aad_len, IMB_ARCH_AVX, 1, 0);
-}
-
 IMB_DLL_LOCAL
 void
 init_chacha20_poly1305_avx2(const void *key, struct chacha20_poly1305_context_data *ctx,
@@ -734,14 +700,6 @@ update_enc_chacha20_poly1305_sse(const void *key, struct chacha20_poly1305_conte
                                         0);
 }
 
-void
-update_enc_chacha20_poly1305_avx(const void *key, struct chacha20_poly1305_context_data *ctx,
-                                 void *dst, const void *src, const uint64_t len)
-{
-        update_chacha20_poly1305_direct(key, ctx, dst, src, len, IMB_DIR_ENCRYPT, IMB_ARCH_AVX, 1,
-                                        0);
-}
-
 void
 update_enc_chacha20_poly1305_avx2(const void *key, struct chacha20_poly1305_context_data *ctx,
                                   void *dst, const void *src, const uint64_t len)
@@ -784,14 +742,6 @@ update_dec_chacha20_poly1305_sse(const void *key, struct chacha20_poly1305_conte
                                         0);
 }
 
-void
-update_dec_chacha20_poly1305_avx(const void *key, struct chacha20_poly1305_context_data *ctx,
-                                 void *dst, const void *src, const uint64_t len)
-{
-        update_chacha20_poly1305_direct(key, ctx, dst, src, len, IMB_DIR_DECRYPT, IMB_ARCH_AVX, 1,
-                                        0);
-}
-
 void
 update_dec_chacha20_poly1305_avx2(const void *key, struct chacha20_poly1305_context_data *ctx,
                                   void *dst, const void *src, const uint64_t len)
@@ -833,13 +783,6 @@ finalize_chacha20_poly1305_sse(struct chacha20_poly1305_context_data *ctx, void
         finalize_chacha20_poly1305_direct(ctx, tag, tag_len, IMB_ARCH_SSE, 1, 0);
 }
 
-void
-finalize_chacha20_poly1305_avx(struct chacha20_poly1305_context_data *ctx, void *tag,
-                               const uint64_t tag_len)
-{
-        finalize_chacha20_poly1305_direct(ctx, tag, tag_len, IMB_ARCH_AVX, 1, 0);
-}
-
 void
 finalize_chacha20_poly1305_avx2(struct chacha20_poly1305_context_data *ctx, void *tag,
                                 const uint64_t tag_len)
