@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2020-2023, Intel Corporation
+  Copyright (c) 2020-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -27,7 +27,6 @@
 
 #include "intel-ipsec-mb.h"
 #include "cpu_feature.h"
-#include "include/noaesni.h"
 #include "error.h"
 
 /**
@@ -61,26 +60,13 @@ init_mb_mgr_auto(IMB_MGR *state, IMB_ARCH *arch)
                 goto init_mb_mgr_auto_ret;
         }
 
-        if ((state->features & IMB_CPUFLAGS_AVX) == IMB_CPUFLAGS_AVX) {
-                init_mb_mgr_avx(state);
-                arch_detected = IMB_ARCH_AVX;
-                goto init_mb_mgr_auto_ret;
-        }
-
         if ((state->features & IMB_CPUFLAGS_SSE) == IMB_CPUFLAGS_SSE) {
                 init_mb_mgr_sse(state);
                 arch_detected = IMB_ARCH_SSE;
                 goto init_mb_mgr_auto_ret;
         }
 
-#ifdef AESNI_EMU
-        if ((state->features & IMB_CPUFLAGS_NO_AESNI) == IMB_CPUFLAGS_NO_AESNI) {
-                init_mb_mgr_sse_no_aesni(state);
-                arch_detected = IMB_ARCH_NOAESNI;
-                goto init_mb_mgr_auto_ret;
-        }
-#endif
-        imb_set_errno(state, ENODEV);
+        imb_set_errno(state, IMB_ERR_MISSING_CPUFLAGS_INIT_MGR);
 
 init_mb_mgr_auto_ret:
         if (arch != NULL)
