@@ -1,5 +1,5 @@
 /*******************************************************************************
-  Copyright (c) 2012-2023, Intel Corporation
+  Copyright (c) 2012-2024, Intel Corporation
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
@@ -223,12 +223,6 @@ md5_one_block_sse(const void *data, void *digest)
         md5_one_block_common(data, digest, ARCH_SSE);
 }
 
-void
-md5_one_block_avx(const void *data, void *digest)
-{
-        md5_one_block_common(data, digest, ARCH_AVX);
-}
-
 void
 md5_one_block_avx2(const void *data, void *digest)
 {
