@@ -1,5 +1,5 @@
 /*****************************************************************************
- Copyright (c) 2017-2023, Intel Corporation
+ Copyright (c) 2017-2024, Intel Corporation
 
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
@@ -30,7 +30,7 @@
 
 #include <stdint.h>
 
-enum arch_type { ARCH_SSE = 0, ARCH_AVX, ARCH_AVX2, ARCH_AVX512, ARCH_NO_AESNI, ARCH_NUMOF };
+enum arch_type { ARCH_SSE = 0, ARCH_AVX2, ARCH_AVX512, ARCH_NUMOF };
 
 #define KBITS(K) (sizeof(K))
 
@@ -51,21 +51,14 @@ struct gcm_ctr_vector {
 };
 
 #define vector(N)                                                                                  \
-        {                                                                                          \
-                K##N, (KBITS(K##N)), IV##N, sizeof(IV##N), A##N, A##N##_len, P##N, sizeof(P##N),   \
-                        C##N, T##N, sizeof(T##N)                                                   \
-        }
+        { K##N, (KBITS(K##N)), IV##N, sizeof(IV##N), A##N,        A##N##_len,                      \
+          P##N, sizeof(P##N),  C##N,  T##N,          sizeof(T##N) }
 
 #define extra_vector(N)                                                                            \
-        {                                                                                          \
-                K##N, (KBITS(K##N)), IV##N, sizeof(IV##N), A##N, A##N##_len, P##N, P##N##_len,     \
-                        C##N, T##N, sizeof(T##N)                                                   \
-        }
+        { K##N, (KBITS(K##N)), IV##N, sizeof(IV##N), A##N,        A##N##_len,                      \
+          P##N, P##N##_len,    C##N,  T##N,          sizeof(T##N) }
 #define ghash_vector(N)                                                                            \
-        {                                                                                          \
-                K##N, (KBITS(K##N)), NULL, 0, NULL, 0, P##N, sizeof(P##N), NULL, T##N,             \
-                        sizeof(T##N)                                                               \
-        }
+        { K##N, (KBITS(K##N)), NULL, 0, NULL, 0, P##N, sizeof(P##N), NULL, T##N, sizeof(T##N) }
 struct MB_MGR;
 
 extern int
