@@ -1,5 +1,5 @@
 /*****************************************************************************
- Copyright (c) 2018-2023, Intel Corporation
+ Copyright (c) 2018-2024, Intel Corporation
 
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
@@ -38,8 +38,6 @@
 int
 hmac_sha1_test(struct IMB_MGR *mb_mgr);
 
-#define MAX_BURST_JOBS 32
-
 extern const struct mac_test hmac_sha1_test_kat_json[];
 static int
 hmac_sha1_job_ok(const struct mac_test *vec, const struct IMB_JOB *job, const uint8_t *auth,
@@ -178,7 +176,7 @@ end2:
 static int
 test_hmac_sha1_burst(struct IMB_MGR *mb_mgr, const struct mac_test *vec, const uint32_t num_jobs)
 {
-        struct IMB_JOB *job, *jobs[MAX_BURST_JOBS] = { NULL };
+        struct IMB_JOB *job, *jobs[IMB_MAX_BURST_SIZE] = { NULL };
         uint8_t padding[16];
         uint8_t **auths = malloc(num_jobs * sizeof(void *));
         uint32_t i = 0, jobs_rx = 0;
@@ -288,7 +286,7 @@ static int
 test_hmac_sha1_hash_burst(struct IMB_MGR *mb_mgr, const struct mac_test *vec,
                           const uint32_t num_jobs)
 {
-        struct IMB_JOB *job, jobs[MAX_BURST_JOBS] = { 0 };
+        struct IMB_JOB *job, jobs[IMB_MAX_BURST_SIZE] = { 0 };
         uint8_t padding[16];
         uint8_t **auths = malloc(num_jobs * sizeof(void *));
         uint32_t i = 0, jobs_rx = 0;
@@ -442,7 +440,7 @@ hmac_sha1_test(struct IMB_MGR *mb_mgr)
         uint32_t num_jobs;
 
         test_suite_start(&ts, "HMAC-SHA1");
-        for (num_jobs = 1; num_jobs <= MAX_BURST_JOBS; num_jobs++)
+        for (num_jobs = 1; num_jobs <= IMB_MAX_BURST_SIZE; num_jobs++)
                 test_hmac_sha1_std_vectors(mb_mgr, num_jobs, &ts);
         errors = test_suite_end(&ts);
 
