@@ -1,5 +1,5 @@
 /*****************************************************************************
- Copyright (c) 2012-2023, Intel Corporation
+ Copyright (c) 2012-2024, Intel Corporation
 
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
@@ -102,7 +102,7 @@ ghash_test(struct IMB_MGR *mb_mgr);
 extern int
 cbc_test(struct IMB_MGR *mb_mgr);
 extern int
-cfb_test(struct IMB_MGR *mb_mgr);
+cfb_one_block_test(struct IMB_MGR *mb_mgr);
 extern int
 ctr_test(struct IMB_MGR *mb_mgr);
 extern int
@@ -113,6 +113,12 @@ extern int
 sm3_test(struct IMB_MGR *mb_mg);
 extern int
 hmac_sm3_test(struct IMB_MGR *mb_mg);
+extern int
+aes_cfb_test(struct IMB_MGR *mb_mg);
+extern int
+sm4_ctr_test(struct IMB_MGR *mb_mgr);
+extern int
+sm4_gcm_test(struct IMB_MGR *mb_mgr);
 
 typedef int (*imb_test_t)(struct IMB_MGR *mb_mgr);
 
@@ -132,7 +138,8 @@ struct imb_test tests[] = {
         { .str = "KAT", .fn = known_answer_test, .enabled = 1 },
         { .str = "DO_TEST", .fn = do_test, .enabled = 1 },
         { .str = "CBC", .fn = cbc_test, .enabled = 1 },
-        { .str = "CFB", .fn = cfb_test, .enabled = 1 },
+        { .str = "CFB_ONE", .fn = cfb_one_block_test, .enabled = 1 },
+        { .str = "CFB", .fn = aes_cfb_test, .enabled = 1 },
         { .str = "CTR", .fn = ctr_test, .enabled = 1 },
         { .str = "PON", .fn = pon_test, .enabled = 1 },
         { .str = "XCBC", .fn = xcbc_test, .enabled = 1 },
@@ -171,7 +178,9 @@ struct imb_test tests[] = {
         { .str = "SM4_ECB", .fn = sm4_ecb_test, .enabled = 1 },
         { .str = "SM4_CBC", .fn = sm4_cbc_test, .enabled = 1 },
         { .str = "SM3", .fn = sm3_test, .enabled = 1 },
-        { .str = "HMAC_SM3", .fn = hmac_sm3_test, .enabled = 1 }
+        { .str = "HMAC_SM3", .fn = hmac_sm3_test, .enabled = 1 },
+        { .str = "SM4_CTR", .fn = sm4_ctr_test, .enabled = 1 },
+        { .str = "SM4_GCM", .fn = sm4_gcm_test, .enabled = 1 }
 };
 
 static int self_test_corrupt = 0;
@@ -214,10 +223,8 @@ usage(const char *name)
                 "--help: Prints this page\n"
                 "--test-type <TEST_NAME>: Run selected test type. <TEST_NAME> is one of %s.\n"
                 "--stop-on-fail: Stop test execution if a test fails\n"
-                "--no-aesni-emu: Don't do AESNI emulation\n"
                 "--no-avx512: Don't do AVX512\n"
                 "--no-avx2: Don't do AVX2\n"
-                "--no-avx: Don't do AVX\n"
                 "--no-sse: Don't do SSE\n"
                 "--auto-detect: Auto detects current architecture "
                 "to run the tests\n  Note: Auto detection "
@@ -242,6 +249,7 @@ print_hw_features(void)
                 uint64_t feat_val;
                 const char *feat_name;
         } feat_tab[] = {
+                { IMB_FEATURE_XSAVE, "XSAVE" },         { IMB_FEATURE_OSXSAVE, "OSXSAVE" },
                 { IMB_FEATURE_SHANI, "SHANI" },         { IMB_FEATURE_AESNI, "AESNI" },
                 { IMB_FEATURE_PCLMULQDQ, "PCLMULQDQ" }, { IMB_FEATURE_CMOV, "CMOV" },
                 { IMB_FEATURE_SSE4_2, "SSE4.2" },       { IMB_FEATURE_AVX, "AVX" },
@@ -249,7 +257,8 @@ print_hw_features(void)
                 { IMB_FEATURE_VAES, "VAES" },           { IMB_FEATURE_VPCLMULQDQ, "VPCLMULQDQ" },
                 { IMB_FEATURE_GFNI, "GFNI" },           { IMB_FEATURE_AVX512_IFMA, "AVX512-IFMA" },
                 { IMB_FEATURE_AVX_IFMA, "AVX-IFMA" },   { IMB_FEATURE_BMI2, "BMI2" },
-                { IMB_FEATURE_HYBRID, "HYBRID-CORE" }
+                { IMB_FEATURE_HYBRID, "HYBRID-CORE" },  { IMB_FEATURE_SM3NI, "SM3NI" },
+                { IMB_FEATURE_SM4NI, "SM4NI" },         { IMB_FEATURE_SHA512NI, "SHA512NI" }
         };
         IMB_MGR *p_mgr = NULL;
         unsigned i;
@@ -298,17 +307,6 @@ check_test_string_arg(const char *param, const char *arg)
         return DIM(tests);
 }
 
-/* Check if expected error for no AESNI Emulation support is returned */
-static int
-check_err_no_aesni_emu(const uint64_t feature_flags, IMB_MGR *p_mgr)
-{
-        if (((feature_flags & IMB_FEATURE_AESNI_EMU) == 0) &&
-            (imb_get_errno(p_mgr) == IMB_ERR_NO_AESNI_EMU))
-                return 1;
-
-        return 0;
-}
-
 static int
 self_test_cb(void *arg, const IMB_SELF_TEST_CALLBACK_DATA *data)
 {
@@ -349,7 +347,6 @@ main(int argc, char **argv)
         uint64_t flags = 0;
         int errors = 0;
         unsigned int stop_on_fail = 0;
-        const uint64_t feat_flags = imb_get_feature_flags();
 
         memset(arch_select, 0xff, sizeof(arch_select));
 
@@ -417,29 +414,17 @@ main(int argc, char **argv)
                 arch_support[j] = arch_support[j] & arch_select[j];
 
         /* Go through architectures */
-        for (atype = IMB_ARCH_NOAESNI; atype < IMB_ARCH_NUM; atype++) {
+        for (atype = IMB_ARCH_SSE; atype < IMB_ARCH_NUM; atype++) {
                 IMB_MGR *p_mgr = NULL;
                 unsigned test_idx;
                 uint64_t used_flags = flags;
 
                 if (!arch_support[atype])
                         continue;
-                if (atype == IMB_ARCH_NOAESNI)
-                        used_flags |= IMB_FLAG_AESNI_OFF;
 
                 p_mgr = alloc_mb_mgr(used_flags);
 
                 if (p_mgr == NULL) {
-                        if (atype == IMB_ARCH_NOAESNI) {
-                                if (check_err_no_aesni_emu(feat_flags, p_mgr)) {
-                                        printf("AESNI Emulation is not enabled."
-                                               " Skipping NOAESNI test.\n");
-                                        continue;
-                                }
-                                printf("Expected %s error, got %s error\n",
-                                       imb_get_strerror(IMB_ERR_NO_AESNI_EMU),
-                                       imb_get_strerror(imb_get_errno(p_mgr)));
-                        }
                         printf("Error allocating MB_MGR structure!\n");
                         return EXIT_FAILURE;
                 }
@@ -449,12 +434,8 @@ main(int argc, char **argv)
 
                 switch (atype) {
                 case IMB_ARCH_SSE:
-                case IMB_ARCH_NOAESNI:
                         init_mb_mgr_sse(p_mgr);
                         break;
-                case IMB_ARCH_AVX:
-                        init_mb_mgr_avx(p_mgr);
-                        break;
                 case IMB_ARCH_AVX2:
                         init_mb_mgr_avx2(p_mgr);
                         break;
